@@ -77,10 +77,14 @@ static struct header_name_func_pair  header_table[] = {
 	,{PROTO_SIP, 			BELLE_SIP_P_PREFERRED_IDENTITY,	(header_parse_func)belle_sip_header_p_preferred_identity_parse}
 	,{PROTO_SIP, 			BELLE_SIP_PRIVACY,				(header_parse_func)belle_sip_header_privacy_parse}
 	,{PROTO_SIP, 			BELLE_SIP_EVENT,				(header_parse_func)belle_sip_header_event_parse}
+	,{PROTO_SIP, 			BELLE_SIP_SUPPORTED,			(header_parse_func)belle_sip_header_supported_parse}
+	,{PROTO_SIP, 			"k",							(header_parse_func)belle_sip_header_supported_parse}
+	,{PROTO_SIP, 			BELLE_SIP_CONTENT_DISPOSITION,	(header_parse_func)belle_sip_header_content_disposition_parse}
+	,{PROTO_SIP, 			BELLE_SIP_ACCEPT,				(header_parse_func)belle_sip_header_accept_parse}
 };
 
 static belle_sip_header_t* belle_header_create(const char* name,const char* value,int protocol) {
-	int i;
+	size_t i;
 	belle_sip_header_t* ret;
 	size_t elements =sizeof(header_table)/sizeof(struct header_name_func_pair);
 
@@ -128,7 +132,7 @@ static void belle_sip_header_destroy(belle_sip_header_t *header){
 
 void belle_sip_header_set_next(belle_sip_header_t* header,belle_sip_header_t* next) {
 	if (next) belle_sip_object_ref(next);
-	if(header->next) belle_sip_object_unref(header->next);
+	if (header->next) belle_sip_object_unref(header->next);
 	header->next = next;
 }
 
@@ -188,6 +192,7 @@ static void belle_sip_header_address_init(belle_sip_header_address_t* object){
 static void belle_sip_header_address_destroy(belle_sip_header_address_t* address) {
 	if (address->displayname) belle_sip_free(address->displayname);
 	if (address->uri) belle_sip_object_unref(address->uri);
+	if (address->absolute_uri) belle_sip_object_unref(address->absolute_uri);
 }
 
 static void belle_sip_header_address_clone(belle_sip_header_address_t *addr, const belle_sip_header_address_t *orig){
@@ -1663,7 +1668,11 @@ BELLESIP_EXPORT time_t belle_sip_header_date_get_time(belle_sip_header_date_t *o
 	char tmp2[16] ={0};
 	int i,j;
 	time_t seconds;
+#ifdef BELLE_SIP_WINDOWS_UNIVERSAL
+	long adjust_timezone;
+#else
 	time_t adjust_timezone;
+#endif
 
 
 	/* time headers are in GMT as spec says */
@@ -1693,20 +1702,24 @@ success:
 	adjust_timezone = 0;
 #else
 	seconds = mktime(&ret);
+#ifdef BELLE_SIP_WINDOWS_UNIVERSAL
+	_get_timezone(&adjust_timezone);
+#else
 	adjust_timezone = timezone;
+#endif
 #endif
 
 	if (seconds==(time_t)-1){
 		belle_sip_error("mktime() failed: %s",strerror(errno));
 		return (time_t)-1;
 	}
-	return seconds-adjust_timezone;
+	return seconds-(time_t)adjust_timezone;
 }
 
 BELLESIP_EXPORT void belle_sip_header_date_set_time(belle_sip_header_date_t *obj, const time_t *utc_time){
 
 	struct tm *ret;
-#ifndef WIN32
+#ifndef _WIN32
 	struct tm gmt;
 	ret=gmtime_r(utc_time,&gmt);
 #else
@@ -1716,7 +1729,19 @@ BELLESIP_EXPORT void belle_sip_header_date_set_time(belle_sip_header_date_t *obj
 	if (obj->date){
 		belle_sip_free(obj->date);
 	}
-	obj->date=belle_sip_strdup_printf("%s, %i %s %i %02i:%02i:%02i GMT",
+/*SIP-date      =  rfc1123-date
+rfc1123-date  =  wkday "," SP date1 SP time SP "GMT"
+date1         =  2DIGIT SP month SP 4DIGIT
+                 ; day month year (e.g., 02 Jun 1982)
+time          =  2DIGIT ":" 2DIGIT ":" 2DIGIT
+                 ; 00:00:00 - 23:59:59
+wkday         =  "Mon" / "Tue" / "Wed"
+                 / "Thu" / "Fri" / "Sat" / "Sun"
+month         =  "Jan" / "Feb" / "Mar" / "Apr"
+                 / "May" / "Jun" / "Jul" / "Aug"
+                 / "Sep" / "Oct" / "Nov" / "Dec"
+*/
+	obj->date=belle_sip_strdup_printf("%s, %02i %s %04i %02i:%02i:%02i GMT",
 			days[ret->tm_wday],ret->tm_mday,months[ret->tm_mon],1900+ret->tm_year,ret->tm_hour,ret->tm_min,ret->tm_sec);
 }
 
@@ -1751,51 +1776,54 @@ belle_sip_header_p_preferred_identity_t* belle_sip_header_p_preferred_identity_c
 	return header;
 }
 
+#define PRIVACY_LIKE_HEADER(header_name, string_name,separator) \
+struct _belle_sip_header_##header_name  { \
+belle_sip_header_t header;\
+belle_sip_list_t* header_name;\
+}; \
+\
+static void belle_sip_header_##header_name##_destroy(belle_sip_header_##header_name##_t* p) {\
+	belle_sip_header_##header_name##_set_##header_name(p,NULL);\
+}\
+\
+static void belle_sip_header_##header_name##_clone(belle_sip_header_##header_name##_t* p, const belle_sip_header_##header_name##_t* orig){\
+	belle_sip_list_t* list=orig->header_name;\
+	for(;list!=NULL;list=list->next){\
+		belle_sip_header_##header_name##_add_##header_name(p,(const char *)list->data);\
+	}\
+}\
+\
+belle_sip_error_code belle_sip_header_##header_name##_marshal(belle_sip_header_##header_name##_t* p, char* buff, size_t buff_size, size_t *offset) {\
+	belle_sip_error_code error=BELLE_SIP_OK;\
+	belle_sip_list_t* list = p->header_name;\
+	error=belle_sip_header_marshal(BELLE_SIP_HEADER(p), buff, buff_size, offset);\
+	if (error!=BELLE_SIP_OK) return error;\
+	for(;list!=NULL;list=list->next){\
+		error=belle_sip_snprintf(buff,buff_size,offset,list==p->header_name ? "%s" : separator" %s",(const char *)list->data);\
+		if (error!=BELLE_SIP_OK) return error;\
+	}\
+	return error;\
+}\
+\
+BELLE_SIP_NEW_HEADER(header_##header_name,header,string_name)\
+BELLE_SIP_PARSE(header_##header_name)\
+belle_sip_list_t* belle_sip_header_##header_name##_get_##header_name(const belle_sip_header_##header_name##_t* p) {\
+	return p->header_name;\
+}\
+SET_ADD_STRING_LIST(belle_sip_header_##header_name,header_name)\
+\
+belle_sip_header_##header_name##_t* belle_sip_header_##header_name##_create(const char* header_name) {\
+	belle_sip_header_##header_name##_t* header=belle_sip_header_##header_name##_new();\
+	belle_sip_header_##header_name##_add_##header_name(header,header_name);\
+	return header;\
+}
+
+
 /******************************
  * Privacy header inherits from header
  *
  ******************************/
-struct _belle_sip_header_privacy  {
-	belle_sip_header_t header;
-	belle_sip_list_t* privacy;
-};
-
-static void belle_sip_header_privacy_destroy(belle_sip_header_privacy_t* p) {
-	belle_sip_header_privacy_set_privacy(p,NULL);
-}
-
-static void belle_sip_header_privacy_clone(belle_sip_header_privacy_t* p, const belle_sip_header_privacy_t* orig){
-	belle_sip_list_t* list=orig->privacy;
-	for(;list!=NULL;list=list->next){
-		belle_sip_header_privacy_add_privacy(p,(const char *)list->data);
-	}
-}
-
-belle_sip_error_code belle_sip_header_privacy_marshal(belle_sip_header_privacy_t* p, char* buff, size_t buff_size, size_t *offset) {
-	belle_sip_error_code error=BELLE_SIP_OK;
-	belle_sip_list_t* list = p->privacy;
-	error=belle_sip_header_marshal(BELLE_SIP_HEADER(p), buff, buff_size, offset);
-	if (error!=BELLE_SIP_OK) return error;
-	for(;list!=NULL;list=list->next){
-		error=belle_sip_snprintf(buff,buff_size,offset,list==p->privacy ? "%s" : ";%s",(const char *)list->data);
-		if (error!=BELLE_SIP_OK) return error;
-	}
-	return error;
-}
-
-BELLE_SIP_NEW_HEADER(header_privacy,header,BELLE_SIP_PRIVACY)
-BELLE_SIP_PARSE(header_privacy)
-belle_sip_list_t* belle_sip_header_privacy_get_privacy(const belle_sip_header_privacy_t* p) {
-	return p->privacy;
-}
-SET_ADD_STRING_LIST(belle_sip_header_privacy,privacy)
-
-belle_sip_header_privacy_t* belle_sip_header_privacy_create(const char* privacy) {
-	belle_sip_header_privacy_t* privacy_header=belle_sip_header_privacy_new();
-	belle_sip_header_privacy_add_privacy(privacy_header,privacy);
-	return privacy_header;
-}
-
+PRIVACY_LIKE_HEADER(privacy,BELLE_SIP_PRIVACY,";")
 /**************************
 * Event header object inherent from parameters
 ****************************
@@ -1834,4 +1862,91 @@ belle_sip_header_event_t* belle_sip_header_event_create (const char* package_nam
 	return event;
 }
 
+/******************************
+ * Supported header inherits from header
+ *
+ ******************************/
+PRIVACY_LIKE_HEADER(supported,BELLE_SIP_SUPPORTED,",")
+
+/******************************
+ * Content-Disposition header inherits from header
+ *
+ ******************************/
+struct _belle_sip_header_content_disposition  {
+	belle_sip_parameters_t parameters;
+	const char* content_disposition;
+};
+
+static void belle_sip_header_content_disposition_destroy(belle_sip_header_content_disposition_t* content_disposition) {
+	DESTROY_STRING(content_disposition,content_disposition);
+}
+
+static void belle_sip_header_content_disposition_clone(belle_sip_header_content_disposition_t* content_disposition,
+													  const belle_sip_header_content_disposition_t *orig ) {
+	CLONE_STRING(belle_sip_header_content_disposition,content_disposition,content_disposition,orig)
+}
+
+belle_sip_error_code belle_sip_header_content_disposition_marshal(belle_sip_header_content_disposition_t* content_disposition, char* buff, size_t buff_size, size_t *offset) {
+	belle_sip_error_code error=belle_sip_header_marshal(BELLE_SIP_HEADER(content_disposition), buff, buff_size, offset);
+	if (error!=BELLE_SIP_OK) return error;
+	error=belle_sip_snprintf(buff,buff_size,offset,"%s",content_disposition->content_disposition);
+	if (error!=BELLE_SIP_OK) return error;
+	error=belle_sip_parameters_marshal(BELLE_SIP_PARAMETERS(content_disposition), buff, buff_size, offset);
+	if (error!=BELLE_SIP_OK) return error;
+	return error;
+}
+
+BELLE_SIP_NEW_HEADER(header_content_disposition,parameters,BELLE_SIP_CONTENT_DISPOSITION)
+BELLE_SIP_PARSE(header_content_disposition)
+GET_SET_STRING(belle_sip_header_content_disposition,content_disposition);
+
+belle_sip_header_content_disposition_t* belle_sip_header_content_disposition_create (const char* value)  {
+	belle_sip_header_content_disposition_t* header=belle_sip_header_content_disposition_new();
+	belle_sip_header_content_disposition_set_content_disposition(header,value);
+	return header;
+}
+
+
+/******************************
+ * Accept header inherits from parameters
+ *
+ ******************************/
+
+struct _belle_sip_header_accept  {
+	belle_sip_parameters_t params_list;
+	const char* type;
+	const char* subtype;
+};
+
+static void belle_sip_header_accept_destroy(belle_sip_header_accept_t* accept) {
+	if (accept->type) belle_sip_free((void*)accept->type);
+	if (accept->subtype) belle_sip_free((void*)accept->subtype);
+}
+
+static void belle_sip_header_accept_clone(belle_sip_header_accept_t* accept, const belle_sip_header_accept_t* orig){
+	CLONE_STRING(belle_sip_header_accept,type,accept,orig);
+	CLONE_STRING(belle_sip_header_accept,subtype,accept,orig);
+}
+
+belle_sip_error_code belle_sip_header_accept_marshal(belle_sip_header_accept_t* accept, char* buff, size_t buff_size, size_t *offset) {
+	belle_sip_error_code error=belle_sip_header_marshal(BELLE_SIP_HEADER(accept), buff, buff_size, offset);
+	if (error!=BELLE_SIP_OK) return error;
+	error=belle_sip_snprintf(buff,buff_size,offset,"%s/%s",accept->type, accept->subtype);
+	if (error!=BELLE_SIP_OK) return error;
+	error=belle_sip_parameters_marshal(&accept->params_list, buff, buff_size, offset);
+	if (error!=BELLE_SIP_OK) return error;
+	return error;
+}
+
+BELLE_SIP_NEW_HEADER(header_accept,parameters,BELLE_SIP_ACCEPT)
+BELLE_SIP_PARSE(header_accept)
+belle_sip_header_accept_t* belle_sip_header_accept_create (const char* type,const char* sub_type) {
+	belle_sip_header_accept_t* header = belle_sip_header_accept_new();
+	belle_sip_header_accept_set_type(header,type);
+	belle_sip_header_accept_set_subtype(header,sub_type);
+	return header;
+}
+GET_SET_STRING(belle_sip_header_accept,type);
+GET_SET_STRING(belle_sip_header_accept,subtype);
+
 
