@@ -205,6 +205,9 @@ BELLE_SIP_DECLARE_VPTR(belle_http_callbacks_t);
 BELLE_SIP_DECLARE_VPTR(belle_tls_verify_policy_t);
 BELLE_SIP_DECLARE_VPTR(belle_http_header_authorization_t);
 BELLE_SIP_DECLARE_VPTR(belle_sip_header_event_t);
+BELLE_SIP_DECLARE_VPTR(belle_sip_header_supported_t);
+BELLE_SIP_DECLARE_VPTR(belle_sip_header_content_disposition_t);
+BELLE_SIP_DECLARE_VPTR(belle_sip_header_accept_t);
 
 BELLE_SIP_DECLARE_CUSTOM_VPTR_BEGIN(belle_sip_resolver_context_t,belle_sip_source_t)
 	void (*cancel)(belle_sip_resolver_context_t *);
@@ -227,8 +230,8 @@ struct belle_sip_source{
 	unsigned long id;
 	belle_sip_fd_t fd;
 	unsigned short events,revents;
-#ifdef WIN32
-	unsigned short armed_events;
+#ifdef _WIN32
+	long armed_events;
 	unsigned short pad;
 #endif
 	int timeout;
@@ -246,6 +249,7 @@ struct belle_sip_source{
 
 void belle_sip_socket_source_init(belle_sip_source_t *s, belle_sip_source_func_t func, void *data, belle_sip_socket_t fd, unsigned int events, unsigned int timeout_value_ms);
 void belle_sip_fd_source_init(belle_sip_source_t *s, belle_sip_source_func_t func, void *data, belle_sip_fd_t fd, unsigned int events, unsigned int timeout_value_ms);
+belle_sip_source_t * belle_sip_fd_source_new(belle_sip_source_func_t func, void *data, belle_sip_fd_t fd, unsigned int events, unsigned int timeout_value_ms);
 void belle_sip_source_uninit(belle_sip_source_t *s);
 void belle_sip_source_set_notify(belle_sip_source_t *s, belle_sip_source_func_t func);
 
@@ -520,6 +524,12 @@ struct belle_sip_stack{
 	char *dns_user_hosts_file; /* used to load additional hosts file for tests */
 	char *dns_resolv_conf; /*used to load custom resolv.conf, for tests*/
 	unsigned char dns_srv_enabled;
+	/*http proxy stuff to be used by both http and sip provider*/
+	char *http_proxy_host;
+	int http_proxy_port;
+	char *http_proxy_username; /*for futur use*/
+	char *http_proxy_passwd; /*for futur use*/
+
 };
 
 belle_sip_hop_t* belle_sip_hop_new(const char* transport, const char *cname, const char* host,int port);
@@ -791,6 +801,7 @@ struct belle_sip_dialog{
 	belle_sip_header_address_t *remote_party;
 	belle_sip_list_t *route_set;
 	belle_sip_header_address_t *remote_target;
+	belle_sip_source_t *expiration_timer;
 	char *local_tag;
 	char *remote_tag;
 	unsigned int local_cseq;
@@ -802,6 +813,8 @@ struct belle_sip_dialog{
 	unsigned char is_secure;
 	unsigned char terminate_on_bye;
 	unsigned char needs_ack;
+	unsigned int remote_invite_cseq; /*needed because multiple trans can be handled whithin invite transaction (I.E UPDATE, PRACK,etc*/
+	unsigned char pending_trans_checking_enabled; /*use to disabled pending transaction check at request creation (testing)*/
 };
 
 belle_sip_dialog_t *belle_sip_dialog_new(belle_sip_transaction_t *t);
@@ -1025,13 +1038,6 @@ BELLE_SIP_DECLARE_CUSTOM_VPTR_END
  * @param[in]	file_type	if not NULL return only the file with the given extension, must include the '.', ex:".pem"
  * @return		a belle_sip list containing all found file or NULL if no file were found or directory doesn't exist. List must be destroyed using belle_sip_list_free_with_data(<ret_list>, belle_sip_free)
  */
-belle_sip_list_t *belle_sip_parse_directory(const char *path, const char *file_type); 
+belle_sip_list_t *belle_sip_parse_directory(const char *path, const char *file_type);
 
-/**
- * create a directory if it doesn't already exists
- *
- * @param[in] 	path		The directory to be created
- * @return 0 in case of succes, -1 otherwise, note it returns -1 if the directory already exists
- */
-int belle_sip_mkdir(const char *path);
 #endif
