@@ -69,18 +69,23 @@ int belle_sip_object_get_object_count(void){
 	return belle_sip_list_size(all_objects);
 }
 
+void belle_sip_object_flush_active_objects(void){
+	//do not free objects so that they are still detected as leaked by valgrind and such
+	all_objects = belle_sip_list_free(all_objects);
+}
+
 void belle_sip_object_dump_active_objects(void){
 	belle_sip_list_t *elem;
-	
+
 	if (all_objects){
-		belle_sip_message("List of leaked objects:");
+		belle_sip_warning("List of leaked objects:");
 		for(elem=all_objects;elem!=NULL;elem=elem->next){
 			belle_sip_object_t *obj=(belle_sip_object_t*)elem->data;
 			char* content= belle_sip_object_to_string(obj);
-			belle_sip_message("%s(%p) ref=%i, content [%10s...]",obj->vptr->type_name,obj,obj->ref,content);
+			belle_sip_warning("%s(%p) ref=%i, content [%10s...]",obj->vptr->type_name,obj,obj->ref,content);
 			belle_sip_free(content);
 		}
-	}else belle_sip_message("No objects leaked.");
+	}else belle_sip_warning("No objects leaked.");
 }
 
 belle_sip_object_t * _belle_sip_object_new(size_t objsize, belle_sip_object_vptr_t *vptr){
@@ -111,22 +116,23 @@ belle_sip_object_t * belle_sip_object_ref(void *obj){
 
 void belle_sip_object_unref(void *ptr){
 	belle_sip_object_t *obj=BELLE_SIP_OBJECT(ptr);
-	if (obj->ref==-1) {
-		belle_sip_error("Object [%p] freed twice !",obj);
+	if (obj->ref <= -1) {
+		belle_sip_error("Object [%p] freed twice or corrupted !",obj);
 		if (obj->vptr && obj->vptr->type_name) belle_sip_error("Object type might be [%s]",obj->vptr->type_name);
 		if (obj->name) belle_sip_error("Object name might be [%s]",obj->name);
 		belle_sip_fatal("Fatal object error encountered, aborting.");
 		return;
 	}
-	if (obj->ref==0 && obj->pool){
-		belle_sip_object_pool_remove(obj->pool,obj);
+	if (obj->vptr->initially_unowned && obj->ref==0){
+		if (obj->pool)
+			belle_sip_object_pool_remove(obj->pool,obj);
 		obj->ref=-1;
 		belle_sip_object_delete(obj);
 		return;
 	}
 	obj->ref--;
-	if (obj->ref==0){
-		obj->ref=-1;
+	if (obj->ref == 0){
+		obj->ref = -1;
 		belle_sip_object_delete(obj);
 	}
 }
@@ -184,7 +190,7 @@ static void _belle_sip_object_uninit(belle_sip_object_t *obj){
 }
 
 static void _belle_sip_object_clone(belle_sip_object_t *obj, const belle_sip_object_t *orig){
-	if (orig->name!=NULL) obj->name=belle_sip_strdup(obj->name);
+	if (orig->name!=NULL) obj->name=belle_sip_strdup(orig->name);
 }
 
 static belle_sip_error_code _belle_object_marshal(belle_sip_object_t* obj, char* buff, size_t buff_size, size_t *offset) {
@@ -590,7 +596,7 @@ char *belle_sip_object_describe(void *obj){
 	return _belle_sip_object_describe_type(o->vptr);
 }
 
-#if !defined(WIN32)
+#if !defined(_WIN32)
 
 #include <dlfcn.h>
 
