@@ -20,6 +20,7 @@
 #include "belle_sip_internal.h"
 #include <limits.h>
 #include <ctype.h>
+#include <wchar.h>
 
 #ifdef ANDROID
 #include "wakelock_internal.h"
@@ -32,7 +33,7 @@ static void channel_end_send_background_task(belle_sip_channel_t *obj);
 static void channel_begin_recv_background_task(belle_sip_channel_t *obj);
 static void channel_end_recv_background_task(belle_sip_channel_t *obj);
 static void channel_process_queue(belle_sip_channel_t *obj);
-static char *make_logbuf(belle_sip_log_level level, const char *buffer, size_t size);
+static char *make_logbuf(belle_sip_channel_t *obj, belle_sip_log_level level, const char *buffer, size_t size);
 static void channel_remove_listener(belle_sip_channel_t *obj, belle_sip_channel_listener_t *l);
 static void free_ewouldblock_buffer(belle_sip_channel_t *obj);
 
@@ -143,7 +144,7 @@ static void fix_incoming_via(belle_sip_request_t *msg, const struct addrinfo* or
  *
  * */
 static int is_token(const char* buff,size_t bufflen ) {
-	int i;
+	size_t i;
 	for (i=0; i<bufflen && buff[i]!='\0';i++) {
 		switch(buff[i]) {
 			case '-' :
@@ -295,6 +296,7 @@ static void belle_sip_channel_message_ready(belle_sip_channel_t *obj){
 	if (bh) belle_sip_body_handler_end_transfer(bh);
 	if (belle_sip_message_is_response(msg)) belle_sip_channel_learn_public_ip_port(obj,BELLE_SIP_RESPONSE(msg));
 	obj->incoming_messages=belle_sip_list_append(obj->incoming_messages,msg);
+	obj->stop_logging_buffer=0;
 	belle_sip_channel_input_stream_reset(&obj->input_stream);
 }
 
@@ -549,8 +551,9 @@ static int belle_sip_channel_process_read_data(belle_sip_channel_t *obj){
 	int ret=BELLE_SIP_CONTINUE;
 
 	/*prevent system to suspend the process until we have finish reading everything from the socket and notified the upper layer*/
-	if (obj->input_stream.state == WAITING_MESSAGE_START)
+	if (obj->input_stream.state == WAITING_MESSAGE_START) {
 		channel_begin_recv_background_task(obj);
+	}
 
 	if (obj->simulated_recv_return>0) {
 		num=belle_sip_channel_recv(obj,obj->input_stream.write_ptr,belle_sip_channel_input_stream_get_buff_length(&obj->input_stream)-1);
@@ -560,19 +563,22 @@ static int belle_sip_channel_process_read_data(belle_sip_channel_t *obj){
 	}
 	if (num>0){
 		char *begin=obj->input_stream.write_ptr;
-		char *logbuf=make_logbuf(BELLE_SIP_LOG_MESSAGE,begin,num);
 		obj->input_stream.write_ptr+=num;
 		/*first null terminate the read buff*/
 		*obj->input_stream.write_ptr='\0';
-		if (num>20) /*to avoid tracing server based keep alives*/
-			belle_sip_message("channel [%p]: received [%i] new bytes from [%s://%s:%i]:\n%s",
-					obj,
-					num,
-					belle_sip_channel_get_transport_name(obj),
-					obj->peer_name,
-					obj->peer_port,
-					logbuf);
-		belle_sip_free(logbuf);
+		if (num>20 || obj->input_stream.state != WAITING_MESSAGE_START ) /*to avoid tracing server based keep alives*/ {
+			char *logbuf = make_logbuf(obj, BELLE_SIP_LOG_MESSAGE,begin,num);
+			if (logbuf) {
+				belle_sip_message("channel [%p]: received [%i] new bytes from [%s://%s:%i]:\n%s",
+						obj,
+						num,
+						belle_sip_channel_get_transport_name(obj),
+						obj->peer_name,
+						obj->peer_port,
+						logbuf);
+				belle_sip_free(logbuf);
+			}
+		}
 		belle_sip_channel_process_stream(obj,FALSE);
 	} else if (num == 0) {
 		/*before closing the channel, check if there was a pending message to receive, whose body acquisition is to be finished.*/
@@ -600,7 +606,8 @@ int belle_sip_channel_process_data(belle_sip_channel_t *obj,unsigned int revents
 	}
 	if (revents & BELLE_SIP_EVENT_WRITE){
 		/*if we are here, this is because we had an EWOULDBLOCK while sending a message*/
-		/*continue to send pending messages but before check the channel is still alive because it may have been closed by belle_sip_channel_process_read_data() above.*/
+		/*continue to send pending messages but before check the channel is still alive because
+		it may have been closed by belle_sip_channel_process_read_data() above.*/
 		if (obj->state == BELLE_SIP_CHANNEL_READY){
 			channel_process_queue(obj);
 		}
@@ -848,8 +855,9 @@ static void channel_connect_next(belle_sip_channel_t *obj){
 }
 
 static void belle_sip_channel_handle_error(belle_sip_channel_t *obj){
-	if (obj->state!=BELLE_SIP_CHANNEL_READY){
-		/* Previous connection attempts were failed (channel could not get ready).*/
+	if (obj->state!=BELLE_SIP_CHANNEL_READY || obj->soft_error){
+		/* Previous connection attempts were failed (channel could not get ready) OR soft error reported*/
+		obj->soft_error = FALSE;
 		/* See if you can retry on an alternate ip address.*/
 		if (obj->current_peer && obj->current_peer->ai_next){ /*obj->current_peer may be null in case of dns error*/
 			obj->current_peer=obj->current_peer->ai_next;
@@ -879,6 +887,12 @@ int belle_sip_channel_notify_timeout(belle_sip_channel_t *obj){
 	return FALSE;
 }
 
+void belle_sip_channel_notify_server_error(belle_sip_channel_t *obj){
+	belle_sip_message("channel[%p]: this server is encountering internal errors, moving to error state to eventually connect to another IP.", obj);
+	obj->soft_error = TRUE;
+	channel_set_state(obj,BELLE_SIP_CHANNEL_ERROR);
+}
+
 void channel_set_state(belle_sip_channel_t *obj, belle_sip_channel_state_t state) {
 	belle_sip_message("channel %p: state %s",obj,belle_sip_channel_state_to_string(state));
 
@@ -911,6 +925,7 @@ static void handle_ewouldblock(belle_sip_channel_t *obj, const char *buffer, siz
 }
 
 static size_t find_non_printable(const char *buffer, size_t size){
+#if 0
 	size_t i;
 	for(i=0;i<size;++i){
 		/*we must check that character is printable, not just ascii
@@ -921,24 +936,42 @@ static size_t find_non_printable(const char *buffer, size_t size){
 		if (!isprint(buffer[i]) && !isspace(buffer[i])) return i;
 	}
 	return size;
+#else
+	size_t i=0;
+	mbstate_t mbs;
+	memset(&mbs, 0, sizeof(mbs));
+	do {
+		size_t valid_multibyte_len = mbrlen(buffer+i, size-i, &mbs);
+		if (valid_multibyte_len == (size_t)-1 || valid_multibyte_len == (size_t)-2 || valid_multibyte_len == 0) break;
+		i += valid_multibyte_len;
+	}while(1);
+	return i;
+#endif
 }
 /*
  * this function is to avoid logging too much or non-ascii data received.
  */
-static char *make_logbuf(belle_sip_log_level level, const char *buffer, size_t size){
+static char *make_logbuf(belle_sip_channel_t *obj, belle_sip_log_level level, const char *buffer, size_t size){
 	char *logbuf;
 	char truncate_msg[128]={0};
 	int limit=7000; /*big message when many ice candidates*/
 
 	if (!belle_sip_log_level_enabled(level)){
-		return belle_sip_malloc0(1);
+		return NULL;
 	}
-	limit=find_non_printable(buffer,MIN(size,limit));
-	if (limit==0){
-		snprintf(truncate_msg,sizeof(truncate_msg)-1,"... (binary data)");
-	} else if (size>limit){
-		snprintf(truncate_msg,sizeof(truncate_msg)-1,"... (first %i bytes shown)",limit);
-		size=limit;
+	if (obj->stop_logging_buffer == 1) {
+		return NULL;
+	}
+	limit=find_non_printable(buffer,MIN((int)size,limit));
+	if (limit != size) {
+		belle_sip_message("channel [%p]: found binary data in buffer, will stop logging it now.", obj);
+		obj->stop_logging_buffer = 1;
+		if (limit==0){
+			snprintf(truncate_msg,sizeof(truncate_msg)-1,"... (binary data)");
+		} else {
+			size=limit;
+			snprintf(truncate_msg,sizeof(truncate_msg)-1,"... (first %i bytes shown)",limit);
+		}
 	}
 
 	if (truncate_msg[0]!=0){
@@ -979,25 +1012,29 @@ static int send_buffer(belle_sip_channel_t *obj, const char *buffer, size_t size
 			channel_set_state(obj,BELLE_SIP_CHANNEL_ERROR);
 		}/*ewouldblock error has to be handled by caller*/
 	}else if (size==(size_t)ret){
-		logbuf=make_logbuf(BELLE_SIP_LOG_MESSAGE, buffer,size);
-		belle_sip_message("channel [%p]: message %s to [%s://%s:%i], size: [%i] bytes\n%s"
-							,obj
-							,obj->stack->send_error==0?"sent":"silently discarded"
-							,belle_sip_channel_get_transport_name(obj)
-							,obj->peer_name
-							,obj->peer_port
-							,ret
-							,logbuf);
+		logbuf=make_logbuf(obj, BELLE_SIP_LOG_MESSAGE, buffer,size);
+		if (logbuf) {
+			belle_sip_message("channel [%p]: message %s to [%s://%s:%i], size: [%i] bytes\n%s"
+								,obj
+								,obj->stack->send_error==0?"sent":"silently discarded"
+								,belle_sip_channel_get_transport_name(obj)
+								,obj->peer_name
+								,obj->peer_port
+								,ret
+								,logbuf);
+		}
 	}else{
-		logbuf=make_logbuf(BELLE_SIP_LOG_MESSAGE,buffer,ret);
-		belle_sip_message("channel [%p]: message partly sent to [%s://%s:%i], sent: [%i/%i] bytes:\n%s"
-							,obj
-							,belle_sip_channel_get_transport_name(obj)
-							,obj->peer_name
-							,obj->peer_port
-							,ret
-							,(int)size
-							,logbuf);
+		logbuf=make_logbuf(obj, BELLE_SIP_LOG_MESSAGE,buffer,ret);
+		if (logbuf) {
+			belle_sip_message("channel [%p]: message partly sent to [%s://%s:%i], sent: [%i/%i] bytes:\n%s"
+								,obj
+								,belle_sip_channel_get_transport_name(obj)
+								,obj->peer_name
+								,obj->peer_port
+								,ret
+								,(int)size
+								,logbuf);
+		}
 	}
 	if (logbuf) belle_sip_free(logbuf);
 	return ret;
@@ -1072,6 +1109,8 @@ static void _send_message(belle_sip_channel_t *obj){
 				do{
 					max_body_len=sizeof(buffer)-1-len;
 					ret=belle_sip_body_handler_send_chunk(bh,msg,(uint8_t*)buffer+len,&max_body_len);
+					if (max_body_len==0)
+						belle_sip_warning("belle_sip_body_handler_send_chunk on channel [%p], 0 bytes read",obj);
 					len+=max_body_len;
 				}while(ret==BELLE_SIP_CONTINUE);
 				belle_sip_body_handler_end_transfer(bh);
@@ -1128,6 +1167,7 @@ static void _send_message(belle_sip_channel_t *obj){
 		belle_sip_source_set_events((belle_sip_source_t*)obj,BELLE_SIP_EVENT_READ|BELLE_SIP_EVENT_ERROR);
 		free_ewouldblock_buffer(obj);
 		obj->out_state=OUTPUT_STREAM_IDLE;
+		obj->stop_logging_buffer=0;
 		belle_sip_object_unref(obj->cur_out_message);
 		obj->cur_out_message=NULL;
 }
@@ -1183,6 +1223,9 @@ static void channel_process_queue(belle_sip_channel_t *obj){
 		send_message(obj, msg);
 		belle_sip_object_unref(msg);
 	}
+	if (obj->state == BELLE_SIP_CHANNEL_READY && obj->out_state == OUTPUT_STREAM_IDLE) {
+		channel_end_send_background_task(obj);
+	}
 
 	belle_sip_object_unref(obj);
 }
@@ -1209,7 +1252,6 @@ void belle_sip_channel_set_ready(belle_sip_channel_t *obj, const struct sockaddr
 	}
 	channel_set_state(obj,BELLE_SIP_CHANNEL_READY);
 	channel_process_queue(obj);
-	channel_end_send_background_task(obj);
 }
 
 static void channel_res_done(void *data, const char *name, struct addrinfo *ai_list){
@@ -1223,12 +1265,13 @@ static void channel_res_done(void *data, const char *name, struct addrinfo *ai_l
 		channel_set_state(obj,BELLE_SIP_CHANNEL_RES_DONE);
 		channel_prepare_continue(obj);
 	}else{
-		belle_sip_error("%s: DNS resolution failed", __FUNCTION__);
+		belle_sip_error("%s: DNS resolution failed for %s", __FUNCTION__, name);
 		channel_set_state(obj,BELLE_SIP_CHANNEL_ERROR);
 	}
 }
 
 void belle_sip_channel_resolve(belle_sip_channel_t *obj){
+	belle_sip_message("channel [%p]: starting resolution of %s", obj, obj->peer_name);
 	channel_set_state(obj,BELLE_SIP_CHANNEL_RES_IN_PROGRESS);
 	if (belle_sip_stack_dns_srv_enabled(obj->stack) && obj->lp!=NULL)
 		obj->resolver_ctx=belle_sip_stack_resolve(obj->stack, belle_sip_channel_get_transport_name_lower_case(obj), obj->peer_name, obj->peer_port, obj->ai_family, channel_res_done, obj);
