@@ -47,8 +47,6 @@ static void belle_sip_dialog_uninit(belle_sip_dialog_t *obj){
 		belle_sip_object_unref(obj->last_transaction);
 	if(obj->privacy)
 		belle_sip_object_unref(obj->privacy);
-/*	if(obj->preferred_identity)
-			belle_sip_object_unref(obj->preferred_identity);*/
 }
 
 BELLE_SIP_DECLARE_NO_IMPLEMENTED_INTERFACES(belle_sip_dialog_t);
@@ -136,6 +134,9 @@ static int belle_sip_dialog_init_as_uas(belle_sip_dialog_t *obj, belle_sip_reque
 	check_route_set(obj->route_set);
 	obj->remote_target=(belle_sip_header_address_t*)belle_sip_object_ref(ct);
 	obj->remote_cseq=belle_sip_header_cseq_get_seq_number(cseq);
+	if (strcmp(belle_sip_request_get_method(req),"INVITE")==0){
+		obj->remote_invite_cseq = belle_sip_header_cseq_get_seq_number(cseq);
+	}
 	/*call id already set */
 	/*remote party already set */
 	obj->local_party=(belle_sip_header_address_t*)belle_sip_object_ref(to);
@@ -202,20 +203,65 @@ static int belle_sip_dialog_init_as_uac(belle_sip_dialog_t *obj, belle_sip_reque
 	return 0;
 }
 
+static int belle_sip_dialog_expired(belle_sip_dialog_t *dialog){
+	belle_sip_message("Dialog [%p] expired", dialog);
+	belle_sip_dialog_delete(dialog);
+	return BELLE_SIP_STOP;
+}
+
+/*returns BELLE_SIP_STOP if the dialog is to be terminated, BELLE_SIP_CONTINUE otherwise*/
+static int belle_sip_dialog_schedule_expiration(belle_sip_dialog_t *dialog, belle_sip_message_t *request){
+	belle_sip_header_expires_t *expires = belle_sip_message_get_header_by_type(request, belle_sip_header_expires_t);
+	int expires_value;
+	
+	if (!expires) return BELLE_SIP_CONTINUE;
+	expires_value = belle_sip_header_expires_get_expires(expires);
+	if (dialog->expiration_timer){
+		belle_sip_main_loop_remove_source(dialog->provider->stack->ml, dialog->expiration_timer);
+		belle_sip_object_unref(dialog->expiration_timer);
+		dialog->expiration_timer = NULL;
+	}
+	belle_sip_message("belle_sip_dialog_schedule_expiration() dialog=%p expires_value=%i", dialog, expires_value);
+	if (expires_value == 0) return BELLE_SIP_STOP;
+	dialog->expiration_timer = belle_sip_main_loop_create_timeout(dialog->provider->stack->ml, 
+					(belle_sip_source_func_t) belle_sip_dialog_expired,
+					dialog,
+					expires_value * 1000,
+					"Dialog expiration");
+	return BELLE_SIP_CONTINUE;
+}
+
 int belle_sip_dialog_establish_full(belle_sip_dialog_t *obj, belle_sip_request_t *req, belle_sip_response_t *resp){
 	belle_sip_header_contact_t *ct=belle_sip_message_get_header_by_type(resp,belle_sip_header_contact_t);
 	belle_sip_header_to_t *to=belle_sip_message_get_header_by_type(resp,belle_sip_header_to_t);
+	const belle_sip_list_t *elem;
 
 	if (strcmp(belle_sip_request_get_method(req),"INVITE")==0)
 		obj->needs_ack=TRUE;
 
-	if (obj->is_server && strcmp(belle_sip_request_get_method(req),"INVITE")==0){
-		belle_sip_dialog_init_200Ok_retrans(obj,resp);
-	} else if (!obj->is_server ) {
+	if (obj->is_server){
+		if (strcmp(belle_sip_request_get_method(req),"INVITE")==0){
+			belle_sip_dialog_init_200Ok_retrans(obj,resp);
+		}
+	} else {
 		if (!ct && !obj->remote_target) {
 			belle_sip_error("Missing contact header in resp [%p] cannot set remote target for dialog [%p]",resp,obj);
 			return -1;
 		}
+		/* 13.2.2.4 2xx Responses
+		   ...
+		   If the dialog identifier in the 2xx response matches the dialog
+		   identifier of an existing dialog, the dialog MUST be transitioned to
+		   the "confirmed" state, and the route set for the dialog MUST be
+		   recomputed based on the 2xx response using the procedures of Section
+		   12.2.1.2.
+		 */
+		obj->route_set=belle_sip_list_free_with_data(obj->route_set,belle_sip_object_unref);
+		for(elem=belle_sip_message_get_headers((belle_sip_message_t*)resp,BELLE_SIP_RECORD_ROUTE);elem!=NULL;elem=elem->next){
+			obj->route_set=belle_sip_list_prepend(obj->route_set,belle_sip_object_ref(belle_sip_header_route_create(
+			                                     (belle_sip_header_address_t*)elem->data)));
+		}
+
 		if (ct) {
 			/*remote Contact header may have changed between early dialog to confirmed*/
 			if (obj->remote_target) belle_sip_object_unref(obj->remote_target);
@@ -320,6 +366,7 @@ static void belle_sip_dialog_stop_200Ok_retrans(belle_sip_dialog_t *obj){
 		obj->last_200Ok=NULL;
 	}
 }
+
 /*
  * return 0 if message should be delivered to the next listener, otherwise, its a retransmision, just keep it
  * */
@@ -329,33 +376,39 @@ int belle_sip_dialog_update(belle_sip_dialog_t *obj, belle_sip_transaction_t* tr
 	belle_sip_request_t *req=belle_sip_transaction_get_request(transaction);
 	belle_sip_response_t *resp=belle_sip_transaction_get_response(transaction);
 	int code=0;
+	int is_invite = strcmp(belle_sip_request_get_method(req),"INVITE")==0;
+	int is_subscribe = strcmp(belle_sip_request_get_method(req),"SUBSCRIBE")==0;
 
 	belle_sip_message("Dialog [%p]: now updated by transaction [%p].",obj, transaction);
 	
-	belle_sip_object_ref(transaction);
-	if (obj->last_transaction) belle_sip_object_unref(obj->last_transaction);
-	obj->last_transaction=transaction;
+	if (resp)
+		code=belle_sip_response_get_status_code(resp);
 	
+	if (as_uas && code == 491) { /**/
+		belle_sip_message("Dialog [%p]: don't update last transaction by transaction [%p].",obj, transaction);
+	} else {
+		belle_sip_object_ref(transaction);
+		if (obj->last_transaction) belle_sip_object_unref(obj->last_transaction);
+		obj->last_transaction=transaction;
+	}
 	if (!as_uas){
 		belle_sip_header_privacy_t *privacy_header=belle_sip_message_get_header_by_type(req,belle_sip_header_privacy_t);
 		SET_OBJECT_PROPERTY(obj,privacy,privacy_header);
 	}
 	
-	if (resp)
-		code=belle_sip_response_get_status_code(resp);
-
-
 	/*first update local/remote cseq*/
 	if (as_uas) {
 		belle_sip_header_cseq_t* cseq=belle_sip_message_get_header_by_type(BELLE_SIP_MESSAGE(req),belle_sip_header_cseq_t);
 		obj->remote_cseq=belle_sip_header_cseq_get_seq_number(cseq);
+		if (is_invite)
+			obj->remote_invite_cseq = belle_sip_header_cseq_get_seq_number(cseq);
 	}
 
 	
 	switch (obj->state){
 		case BELLE_SIP_DIALOG_NULL:
-			/*alway establish a dialog*/
-			if (code>100 && code<300 && (strcmp(belle_sip_request_get_method(req),"INVITE")==0 || strcmp(belle_sip_request_get_method(req),"SUBSCRIBE")==0)) {
+			/*always establish a dialog*/
+			if (code>100 && code<300 && (is_invite || is_subscribe)) {
 				belle_sip_dialog_establish(obj,req,resp);
 				if (code<200){
 					set_state(obj,BELLE_SIP_DIALOG_EARLY);
@@ -364,7 +417,7 @@ int belle_sip_dialog_update(belle_sip_dialog_t *obj, belle_sip_transaction_t* tr
 			}/* no break*/
 		case BELLE_SIP_DIALOG_EARLY:
 			/*don't terminate dialog for UPDATE*/
-			if (code>=300 && (strcmp(belle_sip_request_get_method(req),"INVITE")==0 || strcmp(belle_sip_request_get_method(req),"SUBSCRIBE")==0)) {
+			if (code>=300 && (is_invite || is_subscribe)) {
 				/*12.3 Termination of a Dialog
 			   	   Independent of the method, if a request outside of a dialog generates
 			   	   a non-2xx final response, any early dialogs created through
@@ -373,11 +426,24 @@ int belle_sip_dialog_update(belle_sip_dialog_t *obj, belle_sip_transaction_t* tr
 					delete_dialog=TRUE;
 					break;
 			}
-			if (code>=200 && code<300 && (strcmp(belle_sip_request_get_method(req),"INVITE")==0 || strcmp(belle_sip_request_get_method(req),"SUBSCRIBE")==0))
+			if (code>=200 && code<300 && (is_invite || is_subscribe)){
 				belle_sip_dialog_establish_full(obj,req,resp);
+			}
+			if (is_subscribe){
+				if (belle_sip_dialog_schedule_expiration(obj, (belle_sip_message_t*)req) == BELLE_SIP_STOP
+					&& (code>=200 || (code==0 && belle_sip_transaction_get_state(transaction)==BELLE_SIP_TRANSACTION_TERMINATED))){
+					/*delete the dialog when the 200Ok for a SUBSCRIBE with expires=0 is received or when
+					 * no response is received at all*/
+					delete_dialog = TRUE;
+				}
+			}
+			if (code < 200 && belle_sip_transaction_get_state(transaction)==BELLE_SIP_TRANSACTION_TERMINATED){
+				/*no response establishing the dialog, and transaction terminated (transport errors)*/
+				delete_dialog=TRUE;
+			}
 			break;
 		case BELLE_SIP_DIALOG_CONFIRMED:
-			if (strcmp(belle_sip_request_get_method(req),"INVITE")==0){
+			if (is_invite){
 				if (code>=200 && code<300){
 					/*refresh the remote_target*/
 					belle_sip_header_contact_t *ct;
@@ -422,6 +488,11 @@ int belle_sip_dialog_update(belle_sip_dialog_t *obj, belle_sip_transaction_t* tr
 					obj->needs_ack=FALSE; /*no longuer need ACK*/
 					if (obj->terminate_on_bye) delete_dialog=TRUE;
 				}
+			}else if (is_subscribe){
+				if (belle_sip_dialog_schedule_expiration(obj, (belle_sip_message_t*)req) == BELLE_SIP_STOP
+					&& (code>=200 || (code==0 && belle_sip_transaction_get_state(transaction)==BELLE_SIP_TRANSACTION_TERMINATED))){
+					delete_dialog = TRUE;
+				}
 			}
 		break;
 		case BELLE_SIP_DIALOG_TERMINATED:
@@ -464,6 +535,7 @@ belle_sip_dialog_t *belle_sip_dialog_new(belle_sip_transaction_t *t){
 	obj=belle_sip_object_new(belle_sip_dialog_t);
 	obj->terminate_on_bye=1;
 	obj->provider=t->provider;
+	obj->pending_trans_checking_enabled=1;
 	
 	if (BELLE_SIP_OBJECT_IS_INSTANCE_OF(t,belle_sip_server_transaction_t)){
 		obj->remote_tag=belle_sip_strdup(from_tag);
@@ -478,7 +550,7 @@ belle_sip_dialog_t *belle_sip_dialog_new(belle_sip_transaction_t *t){
 		obj->is_server=FALSE;
 		for(predefined_routes=belle_sip_message_get_headers((belle_sip_message_t*)t->request,BELLE_SIP_ROUTE);
 			predefined_routes!=NULL;predefined_routes=predefined_routes->next){
-			obj->route_set=belle_sip_list_append(obj->route_set,belle_sip_object_ref(predefined_routes->data));	
+			obj->route_set=belle_sip_list_append(obj->route_set,belle_sip_object_ref(predefined_routes->data));
 		}
 	}
 	belle_sip_message("New %s dialog [%p] , local tag [%s], remote tag [%s]"
@@ -536,6 +608,11 @@ belle_sip_request_t *belle_sip_dialog_create_ack(belle_sip_dialog_t *obj, unsign
 static belle_sip_request_t *create_request(belle_sip_dialog_t *obj, const char *method, int full){
 	belle_sip_request_t *req;
 	
+	if (!obj->remote_target){
+		belle_sip_error("dialog [%p]: no remote_target set, unable to create request.", obj);
+		return NULL;
+	}
+	
 	req=belle_sip_request_create(belle_sip_header_address_get_uri(obj->remote_target),
 	                                                method,
 	                                                obj->call_id,
@@ -566,7 +643,9 @@ belle_sip_request_t * belle_sip_dialog_create_queued_request(belle_sip_dialog_t
 		return NULL;
 	}
 	req=create_request(obj,method,FALSE);
-	req->dialog_queued=TRUE;
+	if (req){
+		req->dialog_queued=TRUE;
+	}
 	return req;
 }
 
@@ -583,7 +662,10 @@ belle_sip_request_t *belle_sip_dialog_create_request(belle_sip_dialog_t *obj, co
 		return NULL;
 	}
 	/*don't prevent to send a BYE in any case */
-	if (strcmp(method,"BYE")!=0 && obj->last_transaction && belle_sip_transaction_state_is_transient(belle_sip_transaction_get_state(obj->last_transaction))){
+	if (	obj->pending_trans_checking_enabled
+			&& strcmp(method,"BYE")!=0
+			&& obj->last_transaction
+			&& belle_sip_transaction_state_is_transient(belle_sip_transaction_get_state(obj->last_transaction))){
 
 		if (obj->state != BELLE_SIP_DIALOG_EARLY && strcmp(method,"UPDATE")!=0) {
 			belle_sip_error("belle_sip_dialog_create_request(): cannot create [%s] request from dialog [%p] while pending [%s] transaction in state [%s]",method,obj,belle_sip_transaction_get_method(obj->last_transaction), belle_sip_transaction_state_to_string(belle_sip_transaction_get_state(obj->last_transaction)));
@@ -656,6 +738,12 @@ belle_sip_request_t *belle_sip_dialog_create_queued_request_from(belle_sip_dialo
 
 void belle_sip_dialog_delete(belle_sip_dialog_t *obj){
 	int dropped_transactions;
+	
+	if (obj->expiration_timer){
+		belle_sip_main_loop_remove_source(obj->provider->stack->ml, obj->expiration_timer);
+		belle_sip_object_unref(obj->expiration_timer);
+		obj->expiration_timer = NULL;
+	}
 	belle_sip_message("dialog [%p] deleted.",obj);
 	belle_sip_dialog_stop_200Ok_retrans(obj); /*if any*/
 	set_state(obj,BELLE_SIP_DIALOG_TERMINATED);
@@ -779,10 +867,15 @@ void belle_sip_dialog_check_ack_sent(belle_sip_dialog_t*obj){
 		belle_sip_request_t *req;
 		belle_sip_error("Your listener did not ACK'd the 200Ok for your INVITE request. The dialog will be terminated.");
 		req=belle_sip_dialog_create_request(obj,"BYE");
-		client_trans=belle_sip_provider_create_client_transaction(obj->provider,req);
-		BELLE_SIP_TRANSACTION(client_trans)->is_internal=TRUE; /*internal transaction, don't bother user with 200ok*/
-		belle_sip_client_transaction_send_request(client_trans);
-		/*call dialog terminated*/
+		if (req){
+			client_trans=belle_sip_provider_create_client_transaction(obj->provider,req);
+			BELLE_SIP_TRANSACTION(client_trans)->is_internal=TRUE; /*internal transaction, don't bother user with 200ok*/
+			belle_sip_client_transaction_send_request(client_trans);
+			/*call dialog terminated*/
+		}else{
+			/*If there is no way to signal the failure to the other party, then force immediate dialog deletion*/
+			belle_sip_dialog_delete(obj);
+		}
 	}
 }
 /*
@@ -806,7 +899,7 @@ static int belle_sip_dialog_handle_200Ok(belle_sip_dialog_t *obj, belle_sip_resp
 
 int belle_sip_dialog_handle_ack(belle_sip_dialog_t *obj, belle_sip_request_t *ack){
 	belle_sip_header_cseq_t *cseq=belle_sip_message_get_header_by_type(ack,belle_sip_header_cseq_t);
-	if (obj->needs_ack && belle_sip_header_cseq_get_seq_number(cseq)==obj->remote_cseq){
+	if (obj->needs_ack && belle_sip_header_cseq_get_seq_number(cseq)==obj->remote_invite_cseq){
 		belle_sip_message("Incoming INVITE has ACK, dialog is happy");
 		obj->needs_ack=FALSE;
 		belle_sip_dialog_stop_200Ok_retrans(obj);
@@ -890,7 +983,9 @@ void belle_sip_dialog_process_queue(belle_sip_dialog_t* dialog){
 	 * This is to let the application handle responses and eventually submit new requests without being blocked.
 	 * Typically when a reINVITE is challenged, we want a chance to re-submit an authenticated request before processing
 	 * queued requests*/
-	belle_sip_main_loop_do_later(dialog->provider->stack->ml,(belle_sip_callback_t)_belle_sip_dialog_process_queue,belle_sip_object_ref(dialog));
+	if (dialog->queued_ct){
+		belle_sip_main_loop_do_later(dialog->provider->stack->ml,(belle_sip_callback_t)_belle_sip_dialog_process_queue,belle_sip_object_ref(dialog));
+	}
 }
 
 void belle_sip_dialog_update_request(belle_sip_dialog_t *dialog, belle_sip_request_t *req){
@@ -901,3 +996,12 @@ void belle_sip_dialog_update_request(belle_sip_dialog_t *dialog, belle_sip_reque
 	belle_sip_request_set_uri(req,belle_sip_header_address_get_uri(dialog->remote_target));
 	belle_sip_header_cseq_set_seq_number(cseq,dialog->local_cseq);
 }
+
+int belle_sip_dialog_pending_trans_checking_enabled( const belle_sip_dialog_t *dialog) {
+	return dialog->pending_trans_checking_enabled;
+}
+
+int belle_sip_dialog_enable_pending_trans_checking(belle_sip_dialog_t *dialog, int value) {
+	dialog->pending_trans_checking_enabled = value;
+	return 0;
+}
