@@ -293,6 +293,20 @@ belle_http_channel_context_t * belle_http_channel_context_new(belle_sip_channel_
 	return obj;
 }
 
+int belle_http_channel_is_busy(belle_sip_channel_t *obj) {
+	belle_sip_list_t *it;
+	if (obj->incoming_messages != NULL || obj->outgoing_messages != NULL) {
+		return 1;
+	}
+	for (it = obj->listeners; it != NULL; it = it->next) {
+		if (BELLE_SIP_IS_INSTANCE_OF(it->data, belle_http_channel_context_t)) {
+			belle_http_channel_context_t *obj = it->data;
+			return obj->pending_requests != NULL;
+		}
+	}
+	return 0;
+}
+
 BELLE_SIP_IMPLEMENT_INTERFACE_BEGIN(belle_http_channel_context_t,belle_sip_channel_listener_t)
 	channel_state_changed,
 	channel_on_message_headers,
@@ -357,7 +371,7 @@ static void fix_request(belle_http_request_t *req){
 	}
 }
 
-static belle_sip_list_t **provider_get_channels(belle_http_provider_t *obj, const char *transport_name){
+belle_sip_list_t **belle_http_provider_get_channels(belle_http_provider_t *obj, const char *transport_name){
 	if (strcasecmp(transport_name,"tcp")==0) return &obj->tcp_channels;
 	else if (strcasecmp(transport_name,"tls")==0) return &obj->tls_channels;
 	else{
@@ -367,9 +381,9 @@ static belle_sip_list_t **provider_get_channels(belle_http_provider_t *obj, cons
 }
 
 static void provider_remove_channel(belle_http_provider_t *obj, belle_sip_channel_t *chan){
-	belle_sip_list_t **channels=provider_get_channels(obj,belle_sip_channel_get_transport_name(chan));
+	belle_sip_list_t **channels=belle_http_provider_get_channels(obj,belle_sip_channel_get_transport_name(chan));
 	*channels=belle_sip_list_remove(*channels,chan);
-	belle_sip_message("channel [%p] removed from http provider.",obj);
+	belle_sip_message("channel [%p] removed from http provider.", chan);
 	belle_sip_object_unref(chan);
 }
 
@@ -384,13 +398,30 @@ static void belle_http_end_background_task(void* data) {
 
 int belle_http_provider_send_request(belle_http_provider_t *obj, belle_http_request_t *req, belle_http_request_listener_t *listener){
 	belle_sip_channel_t *chan;
+	belle_sip_list_t **channels;
 	belle_sip_hop_t *hop=belle_sip_hop_new_from_generic_uri(req->orig_uri ? req->orig_uri : req->req_uri);
-	belle_sip_list_t **channels=provider_get_channels(obj,hop->transport);
+
+	if (hop->host == NULL){
+		belle_sip_error("belle_http_provider_send_request(): no host defined in request uri.");
+		belle_sip_object_unref(hop);
+		return -1;
+	}
+
+	channels = belle_http_provider_get_channels(obj,hop->transport);
 
 	if (listener) belle_http_request_set_listener(req,listener);
 
 	chan=belle_sip_channel_find_from_list(*channels,obj->ai_family, hop);
 
+	if (chan) {
+		// we cannot use the same channel for multiple requests yet since only the first
+		// one will be processed. Instead of queuing/serializing requests on a single channel,
+		// we currently create one channel per request if needed.
+		if (belle_http_channel_is_busy(chan)) {
+			belle_sip_message("%s: found an available channel but was busy, creating a new one", __FUNCTION__);
+			chan = NULL;
+		}
+	}
 	if (!chan){
 		if (strcasecmp(hop->transport,"tcp")==0){
 			chan=belle_sip_stream_channel_new_client(obj->stack,obj->bind_ip,0,hop->cname,hop->host,hop->port);
@@ -401,7 +432,8 @@ int belle_http_provider_send_request(belle_http_provider_t *obj, belle_http_requ
 		}
 #endif
 		if (!chan){
-			belle_sip_error("belle_http_provider_send_request(): cannot create channel for [%s:%s:%i]",hop->transport,hop->cname,hop->port);
+			belle_sip_error("%s: cannot create channel for [%s:%s:%i]", __FUNCTION__, hop->transport, hop->cname,
+							hop->port);
 			belle_sip_object_unref(hop);
 			return -1;
 		}
@@ -432,6 +464,11 @@ void belle_http_provider_cancel_request(belle_http_provider_t *obj, belle_http_r
 	if (req->channel){
 		// Keep the list of the outgoing messages of the channel...
 		outgoing_messages = belle_sip_list_copy_with_data(req->channel->outgoing_messages,(void* (*)(void*))belle_sip_object_ref);
+		if (outgoing_messages && outgoing_messages->data == req){
+			/*our request didn't go out; so drop it.*/
+			outgoing_messages = belle_sip_list_remove(outgoing_messages ,req);
+			belle_sip_object_unref(req);
+		}
 		/*protect the channel from being destroyed before removing it (removing it will unref it)*/
 		belle_sip_object_ref(req->channel);
 		provider_remove_channel(obj, req->channel);
@@ -449,4 +486,18 @@ int belle_http_provider_set_tls_verify_policy(belle_http_provider_t *obj, belle_
 	return 0;
 }
 
+void belle_http_provider_set_recv_error(belle_http_provider_t *obj, int recv_error) {
+	belle_sip_list_t *it;
+	
+	for(it=obj->tcp_channels;it!=NULL;it=it->next){
+		belle_sip_channel_t *chan = (belle_sip_channel_t*)it->data;
+		chan->simulated_recv_return=recv_error;
+		chan->base.notify_required=(recv_error<=0);
+	}
+	for(it=obj->tls_channels;it!=NULL;it=it->next){
+		belle_sip_channel_t *chan = (belle_sip_channel_t*)it->data;
+		chan->simulated_recv_return=recv_error;
+		chan->base.notify_required=(recv_error<=0);
+	}
+}
 
