@@ -248,8 +248,19 @@ void belle_sip_message_remove_header(belle_sip_message_t *msg, const char *heade
 		belle_sip_headers_container_delete(headers_container);
 	}
 }
-
-
+void belle_sip_message_remove_header_from_ptr(belle_sip_message_t *msg, belle_sip_header_t* header) {
+	headers_container_t* headers_container = belle_sip_headers_container_get(msg,belle_sip_header_get_name(header));
+	belle_sip_list_t* it;
+	it=belle_sip_list_find(headers_container->header_list,header);
+	if (it) {
+		belle_sip_object_unref(header);
+		headers_container->header_list=belle_sip_list_delete_link(headers_container->header_list,it);
+		if (belle_sip_list_size(headers_container->header_list) == 0) {
+			belle_sip_list_remove(msg->header_list,headers_container);
+			belle_sip_headers_container_delete(headers_container);
+		}
+	}
+}
 /*
 belle_sip_error_code belle_sip_message_named_headers_marshal(belle_sip_message_t *message, const char* header_name, char* buff, size_t buff_size, size_t *offset) {
 	belle_sip_error_code error=BELLE_SIP_OK;
@@ -320,10 +331,13 @@ belle_sip_error_code belle_sip_headers_marshal(belle_sip_message_t *message, cha
 			}else
 #endif
 			{
-				error=belle_sip_object_marshal(BELLE_SIP_OBJECT(h),buff,buff_size,offset);
-				if (error!=BELLE_SIP_OK) return error;
-				error=belle_sip_snprintf(buff,buff_size,offset,"%s","\r\n");
-				if (error!=BELLE_SIP_OK) return error;
+				while (h!=NULL) { /*header can be chained*/
+					error=belle_sip_object_marshal(BELLE_SIP_OBJECT(h),buff,buff_size,offset);
+					if (error!=BELLE_SIP_OK) return error;
+					error=belle_sip_snprintf(buff,buff_size,offset,"%s","\r\n");
+					if (error!=BELLE_SIP_OK) return error;
+					h= belle_sip_header_get_next(h);
+				}
 			}
 		}
 	}
@@ -359,7 +373,7 @@ static void belle_sip_request_clone(belle_sip_request_t *request, const belle_si
 }
 
 belle_sip_error_code belle_sip_request_marshal(belle_sip_request_t* request, char* buff, size_t buff_size, size_t *offset) {
-	belle_sip_error_code error=belle_sip_snprintf(buff,buff_size,offset,"%s ",belle_sip_request_get_method(request));
+	belle_sip_error_code error=belle_sip_snprintf(buff,buff_size,offset,"%s ",belle_sip_request_get_method(request) ? belle_sip_request_get_method(request) : "");
 
 	if (error!=BELLE_SIP_OK) return error;
 	if (request->uri)
