@@ -19,8 +19,6 @@
 #include "belle-sip/belle-sip.h"
 #include "belle_sip_tester.h"
 #include "port.h"
-#include <stdio.h>
-#include "CUnit/Basic.h"
 
 
 //v=0
@@ -57,49 +55,56 @@ static belle_sdp_attribute_t* attribute_parse_marshall_parse_clone(const char* r
 
 static void test_attribute(void) {
 	belle_sdp_attribute_t* lAttribute = attribute_parse_marshall_parse_clone("a=rtpmap:101 telephone-event/8000");
-	CU_ASSERT_STRING_EQUAL(belle_sdp_attribute_get_name(lAttribute), "rtpmap");
-	CU_ASSERT_STRING_EQUAL(belle_sdp_attribute_get_value(lAttribute), "101 telephone-event/8000");
-	CU_ASSERT_TRUE(belle_sdp_attribute_has_value(lAttribute));
+	BC_ASSERT_STRING_EQUAL(belle_sdp_attribute_get_name(lAttribute), "rtpmap");
+	BC_ASSERT_STRING_EQUAL(belle_sdp_attribute_get_value(lAttribute), "101 telephone-event/8000");
+	BC_ASSERT_TRUE(belle_sdp_attribute_has_value(lAttribute));
 	belle_sip_object_unref(BELLE_SIP_OBJECT(lAttribute));
 }
 
 static void test_attribute_2(void) {
 	belle_sdp_attribute_t* lAttribute = attribute_parse_marshall_parse_clone("a=ice-pwd:31ec21eb38b2ec6d36e8dc7b");
-	CU_ASSERT_STRING_EQUAL(belle_sdp_attribute_get_name(lAttribute), "ice-pwd");
-	CU_ASSERT_STRING_EQUAL(belle_sdp_attribute_get_value(lAttribute), "31ec21eb38b2ec6d36e8dc7b");
-	CU_ASSERT_TRUE(belle_sdp_attribute_has_value(lAttribute));
+	BC_ASSERT_STRING_EQUAL(belle_sdp_attribute_get_name(lAttribute), "ice-pwd");
+	BC_ASSERT_STRING_EQUAL(belle_sdp_attribute_get_value(lAttribute), "31ec21eb38b2ec6d36e8dc7b");
+	BC_ASSERT_TRUE(belle_sdp_attribute_has_value(lAttribute));
 	belle_sip_object_unref(BELLE_SIP_OBJECT(lAttribute));
+
+	lAttribute = attribute_parse_marshall_parse_clone("a=alt:1 1 : e2br+9PL Eu1qGlQ9 10.211.55.3 8988");
+	BC_ASSERT_STRING_EQUAL(belle_sdp_attribute_get_name(lAttribute), "alt");
+	BC_ASSERT_STRING_EQUAL(belle_sdp_attribute_get_value(lAttribute), "1 1 : e2br+9PL Eu1qGlQ9 10.211.55.3 8988");
+	BC_ASSERT_TRUE(belle_sdp_attribute_has_value(lAttribute));
+	belle_sip_object_unref(BELLE_SIP_OBJECT(lAttribute));
+
 }
 
 static void test_rtcp_fb_attribute(void) {
 	belle_sdp_rtcp_fb_attribute_t* lAttribute;
 
 	lAttribute = BELLE_SDP_RTCP_FB_ATTRIBUTE(attribute_parse_marshall_parse_clone("a=rtcp-fb:* ack"));
-	CU_ASSERT_STRING_EQUAL(belle_sdp_attribute_get_name(BELLE_SDP_ATTRIBUTE(lAttribute)), "rtcp-fb");
-	CU_ASSERT_EQUAL(belle_sdp_rtcp_fb_attribute_get_id(lAttribute), -1);
-	CU_ASSERT_EQUAL(belle_sdp_rtcp_fb_attribute_get_type(lAttribute), BELLE_SDP_RTCP_FB_ACK);
-	CU_ASSERT_EQUAL(belle_sdp_rtcp_fb_attribute_get_param(lAttribute), BELLE_SDP_RTCP_FB_NONE);
+	BC_ASSERT_STRING_EQUAL(belle_sdp_attribute_get_name(BELLE_SDP_ATTRIBUTE(lAttribute)), "rtcp-fb");
+	BC_ASSERT_EQUAL(belle_sdp_rtcp_fb_attribute_get_id(lAttribute), -1, int, "%d");
+	BC_ASSERT_EQUAL(belle_sdp_rtcp_fb_attribute_get_type(lAttribute), BELLE_SDP_RTCP_FB_ACK, int, "%d");
+	BC_ASSERT_EQUAL(belle_sdp_rtcp_fb_attribute_get_param(lAttribute), BELLE_SDP_RTCP_FB_NONE, int, "%d");
 	belle_sip_object_unref(BELLE_SIP_OBJECT(lAttribute));
 
 	lAttribute = BELLE_SDP_RTCP_FB_ATTRIBUTE(attribute_parse_marshall_parse_clone("a=rtcp-fb:98 nack rpsi"));
-	CU_ASSERT_STRING_EQUAL(belle_sdp_attribute_get_name(BELLE_SDP_ATTRIBUTE(lAttribute)), "rtcp-fb");
-	CU_ASSERT_EQUAL(belle_sdp_rtcp_fb_attribute_get_id(lAttribute), 98);
-	CU_ASSERT_EQUAL(belle_sdp_rtcp_fb_attribute_get_type(lAttribute), BELLE_SDP_RTCP_FB_NACK);
-	CU_ASSERT_EQUAL(belle_sdp_rtcp_fb_attribute_get_param(lAttribute), BELLE_SDP_RTCP_FB_RPSI);
+	BC_ASSERT_STRING_EQUAL(belle_sdp_attribute_get_name(BELLE_SDP_ATTRIBUTE(lAttribute)), "rtcp-fb");
+	BC_ASSERT_EQUAL(belle_sdp_rtcp_fb_attribute_get_id(lAttribute), 98, int, "%d");
+	BC_ASSERT_EQUAL(belle_sdp_rtcp_fb_attribute_get_type(lAttribute), BELLE_SDP_RTCP_FB_NACK, int, "%d");
+	BC_ASSERT_EQUAL(belle_sdp_rtcp_fb_attribute_get_param(lAttribute), BELLE_SDP_RTCP_FB_RPSI, int, "%d");
 	belle_sip_object_unref(BELLE_SIP_OBJECT(lAttribute));
 
 	lAttribute = BELLE_SDP_RTCP_FB_ATTRIBUTE(attribute_parse_marshall_parse_clone("a=rtcp-fb:* trr-int 3"));
-	CU_ASSERT_STRING_EQUAL(belle_sdp_attribute_get_name(BELLE_SDP_ATTRIBUTE(lAttribute)), "rtcp-fb");
-	CU_ASSERT_EQUAL(belle_sdp_rtcp_fb_attribute_get_id(lAttribute), -1);
-	CU_ASSERT_EQUAL(belle_sdp_rtcp_fb_attribute_get_type(lAttribute), BELLE_SDP_RTCP_FB_TRR_INT);
-	CU_ASSERT_EQUAL(belle_sdp_rtcp_fb_attribute_get_trr_int(lAttribute), 3);
+	BC_ASSERT_STRING_EQUAL(belle_sdp_attribute_get_name(BELLE_SDP_ATTRIBUTE(lAttribute)), "rtcp-fb");
+	BC_ASSERT_EQUAL(belle_sdp_rtcp_fb_attribute_get_id(lAttribute), -1, int, "%d");
+	BC_ASSERT_EQUAL(belle_sdp_rtcp_fb_attribute_get_type(lAttribute), BELLE_SDP_RTCP_FB_TRR_INT, int, "%d");
+	BC_ASSERT_EQUAL(belle_sdp_rtcp_fb_attribute_get_trr_int(lAttribute), 3, int, "%d");
 	belle_sip_object_unref(BELLE_SIP_OBJECT(lAttribute));
 
 	lAttribute = BELLE_SDP_RTCP_FB_ATTRIBUTE(attribute_parse_marshall_parse_clone("a=rtcp-fb:103 ccm fir"));
-	CU_ASSERT_STRING_EQUAL(belle_sdp_attribute_get_name(BELLE_SDP_ATTRIBUTE(lAttribute)), "rtcp-fb");
-	CU_ASSERT_EQUAL(belle_sdp_rtcp_fb_attribute_get_id(lAttribute), 103);
-	CU_ASSERT_EQUAL(belle_sdp_rtcp_fb_attribute_get_type(lAttribute), BELLE_SDP_RTCP_FB_CCM);
-	CU_ASSERT_EQUAL(belle_sdp_rtcp_fb_attribute_get_param(lAttribute), BELLE_SDP_RTCP_FB_FIR);
+	BC_ASSERT_STRING_EQUAL(belle_sdp_attribute_get_name(BELLE_SDP_ATTRIBUTE(lAttribute)), "rtcp-fb");
+	BC_ASSERT_EQUAL(belle_sdp_rtcp_fb_attribute_get_id(lAttribute), 103, int, "%d");
+	BC_ASSERT_EQUAL(belle_sdp_rtcp_fb_attribute_get_type(lAttribute), BELLE_SDP_RTCP_FB_CCM, int, "%d");
+	BC_ASSERT_EQUAL(belle_sdp_rtcp_fb_attribute_get_param(lAttribute), BELLE_SDP_RTCP_FB_FIR, int, "%d");
 	belle_sip_object_unref(BELLE_SIP_OBJECT(lAttribute));
 }
 
@@ -107,47 +112,47 @@ static void test_rtcp_xr_attribute(void) {
 	belle_sdp_rtcp_xr_attribute_t* lAttribute;
 
 	lAttribute = BELLE_SDP_RTCP_XR_ATTRIBUTE(attribute_parse_marshall_parse_clone("a=rtcp-xr"));
-	CU_ASSERT_STRING_EQUAL(belle_sdp_attribute_get_name(BELLE_SDP_ATTRIBUTE(lAttribute)), "rtcp-xr");
-	CU_ASSERT_TRUE(belle_sdp_rtcp_xr_attribute_has_stat_summary(lAttribute) == FALSE);
-	CU_ASSERT_TRUE(belle_sdp_rtcp_xr_attribute_has_voip_metrics(lAttribute) == FALSE);
+	BC_ASSERT_STRING_EQUAL(belle_sdp_attribute_get_name(BELLE_SDP_ATTRIBUTE(lAttribute)), "rtcp-xr");
+	BC_ASSERT_TRUE(belle_sdp_rtcp_xr_attribute_has_stat_summary(lAttribute) == FALSE);
+	BC_ASSERT_TRUE(belle_sdp_rtcp_xr_attribute_has_voip_metrics(lAttribute) == FALSE);
 	belle_sip_object_unref(BELLE_SIP_OBJECT(lAttribute));
 
 	lAttribute = BELLE_SDP_RTCP_XR_ATTRIBUTE(attribute_parse_marshall_parse_clone("a=rtcp-xr:rcvr-rtt=all:10"));
-	CU_ASSERT_STRING_EQUAL(belle_sdp_attribute_get_name(BELLE_SDP_ATTRIBUTE(lAttribute)), "rtcp-xr");
-	CU_ASSERT_STRING_EQUAL(belle_sdp_rtcp_xr_attribute_get_rcvr_rtt_mode(lAttribute), "all");
-	CU_ASSERT_EQUAL(belle_sdp_rtcp_xr_attribute_get_rcvr_rtt_max_size(lAttribute), 10);
+	BC_ASSERT_STRING_EQUAL(belle_sdp_attribute_get_name(BELLE_SDP_ATTRIBUTE(lAttribute)), "rtcp-xr");
+	BC_ASSERT_STRING_EQUAL(belle_sdp_rtcp_xr_attribute_get_rcvr_rtt_mode(lAttribute), "all");
+	BC_ASSERT_EQUAL(belle_sdp_rtcp_xr_attribute_get_rcvr_rtt_max_size(lAttribute), 10, int, "%d");
 	belle_sip_object_unref(BELLE_SIP_OBJECT(lAttribute));
 
 	lAttribute = BELLE_SDP_RTCP_XR_ATTRIBUTE(attribute_parse_marshall_parse_clone("a=rtcp-xr:stat-summary"));
-	CU_ASSERT_STRING_EQUAL(belle_sdp_attribute_get_name(BELLE_SDP_ATTRIBUTE(lAttribute)), "rtcp-xr");
-	CU_ASSERT_PTR_NULL(belle_sdp_rtcp_xr_attribute_get_rcvr_rtt_mode(lAttribute));
-	CU_ASSERT_TRUE(belle_sdp_rtcp_xr_attribute_has_stat_summary(lAttribute) == TRUE);
-	CU_ASSERT_TRUE(belle_sdp_rtcp_xr_attribute_has_voip_metrics(lAttribute) == FALSE);
+	BC_ASSERT_STRING_EQUAL(belle_sdp_attribute_get_name(BELLE_SDP_ATTRIBUTE(lAttribute)), "rtcp-xr");
+	BC_ASSERT_PTR_NULL(belle_sdp_rtcp_xr_attribute_get_rcvr_rtt_mode(lAttribute));
+	BC_ASSERT_TRUE(belle_sdp_rtcp_xr_attribute_has_stat_summary(lAttribute) == TRUE);
+	BC_ASSERT_TRUE(belle_sdp_rtcp_xr_attribute_has_voip_metrics(lAttribute) == FALSE);
 	belle_sip_object_unref(BELLE_SIP_OBJECT(lAttribute));
 
 	lAttribute = BELLE_SDP_RTCP_XR_ATTRIBUTE(attribute_parse_marshall_parse_clone("a=rtcp-xr:stat-summary=loss,jitt"));
-	CU_ASSERT_STRING_EQUAL(belle_sdp_attribute_get_name(BELLE_SDP_ATTRIBUTE(lAttribute)), "rtcp-xr");
-	CU_ASSERT_TRUE(belle_sdp_rtcp_xr_attribute_has_stat_summary(lAttribute) == TRUE);
-	CU_ASSERT_PTR_NOT_NULL(belle_sip_list_find_custom(belle_sdp_rtcp_xr_attribute_get_stat_summary_flags(lAttribute), (belle_sip_compare_func)strcasecmp, "loss"));
-	CU_ASSERT_PTR_NOT_NULL(belle_sip_list_find_custom(belle_sdp_rtcp_xr_attribute_get_stat_summary_flags(lAttribute), (belle_sip_compare_func)strcasecmp, "jitt"));
-	CU_ASSERT_PTR_NULL(belle_sip_list_find_custom(belle_sdp_rtcp_xr_attribute_get_stat_summary_flags(lAttribute), (belle_sip_compare_func)strcasecmp, "HL"));
+	BC_ASSERT_STRING_EQUAL(belle_sdp_attribute_get_name(BELLE_SDP_ATTRIBUTE(lAttribute)), "rtcp-xr");
+	BC_ASSERT_TRUE(belle_sdp_rtcp_xr_attribute_has_stat_summary(lAttribute) == TRUE);
+	BC_ASSERT_PTR_NOT_NULL(belle_sip_list_find_custom(belle_sdp_rtcp_xr_attribute_get_stat_summary_flags(lAttribute), (belle_sip_compare_func)strcasecmp, "loss"));
+	BC_ASSERT_PTR_NOT_NULL(belle_sip_list_find_custom(belle_sdp_rtcp_xr_attribute_get_stat_summary_flags(lAttribute), (belle_sip_compare_func)strcasecmp, "jitt"));
+	BC_ASSERT_PTR_NULL(belle_sip_list_find_custom(belle_sdp_rtcp_xr_attribute_get_stat_summary_flags(lAttribute), (belle_sip_compare_func)strcasecmp, "HL"));
 	belle_sip_object_unref(BELLE_SIP_OBJECT(lAttribute));
 
 	lAttribute = BELLE_SDP_RTCP_XR_ATTRIBUTE(attribute_parse_marshall_parse_clone("a=rtcp-xr:voip-metrics"));
-	CU_ASSERT_STRING_EQUAL(belle_sdp_attribute_get_name(BELLE_SDP_ATTRIBUTE(lAttribute)), "rtcp-xr");
-	CU_ASSERT_TRUE(belle_sdp_rtcp_xr_attribute_has_stat_summary(lAttribute) == FALSE);
-	CU_ASSERT_TRUE(belle_sdp_rtcp_xr_attribute_has_voip_metrics(lAttribute) == TRUE);
+	BC_ASSERT_STRING_EQUAL(belle_sdp_attribute_get_name(BELLE_SDP_ATTRIBUTE(lAttribute)), "rtcp-xr");
+	BC_ASSERT_TRUE(belle_sdp_rtcp_xr_attribute_has_stat_summary(lAttribute) == FALSE);
+	BC_ASSERT_TRUE(belle_sdp_rtcp_xr_attribute_has_voip_metrics(lAttribute) == TRUE);
 	belle_sip_object_unref(BELLE_SIP_OBJECT(lAttribute));
 
 	lAttribute = BELLE_SDP_RTCP_XR_ATTRIBUTE(attribute_parse_marshall_parse_clone("a=rtcp-xr:rcvr-rtt=sender stat-summary=loss,dup,jitt,TTL voip-metrics"));
-	CU_ASSERT_STRING_EQUAL(belle_sdp_attribute_get_name(BELLE_SDP_ATTRIBUTE(lAttribute)), "rtcp-xr");
-	CU_ASSERT_STRING_EQUAL(belle_sdp_rtcp_xr_attribute_get_rcvr_rtt_mode(lAttribute), "sender");
-	CU_ASSERT_TRUE(belle_sdp_rtcp_xr_attribute_has_stat_summary(lAttribute) == TRUE);
-	CU_ASSERT_PTR_NOT_NULL(belle_sip_list_find_custom(belle_sdp_rtcp_xr_attribute_get_stat_summary_flags(lAttribute), (belle_sip_compare_func)strcasecmp, "loss"));
-	CU_ASSERT_PTR_NOT_NULL(belle_sip_list_find_custom(belle_sdp_rtcp_xr_attribute_get_stat_summary_flags(lAttribute), (belle_sip_compare_func)strcasecmp, "dup"));
-	CU_ASSERT_PTR_NOT_NULL(belle_sip_list_find_custom(belle_sdp_rtcp_xr_attribute_get_stat_summary_flags(lAttribute), (belle_sip_compare_func)strcasecmp, "jitt"));
-	CU_ASSERT_PTR_NOT_NULL(belle_sip_list_find_custom(belle_sdp_rtcp_xr_attribute_get_stat_summary_flags(lAttribute), (belle_sip_compare_func)strcasecmp, "TTL"));
-	CU_ASSERT_TRUE(belle_sdp_rtcp_xr_attribute_has_voip_metrics(lAttribute) == TRUE);
+	BC_ASSERT_STRING_EQUAL(belle_sdp_attribute_get_name(BELLE_SDP_ATTRIBUTE(lAttribute)), "rtcp-xr");
+	BC_ASSERT_STRING_EQUAL(belle_sdp_rtcp_xr_attribute_get_rcvr_rtt_mode(lAttribute), "sender");
+	BC_ASSERT_TRUE(belle_sdp_rtcp_xr_attribute_has_stat_summary(lAttribute) == TRUE);
+	BC_ASSERT_PTR_NOT_NULL(belle_sip_list_find_custom(belle_sdp_rtcp_xr_attribute_get_stat_summary_flags(lAttribute), (belle_sip_compare_func)strcasecmp, "loss"));
+	BC_ASSERT_PTR_NOT_NULL(belle_sip_list_find_custom(belle_sdp_rtcp_xr_attribute_get_stat_summary_flags(lAttribute), (belle_sip_compare_func)strcasecmp, "dup"));
+	BC_ASSERT_PTR_NOT_NULL(belle_sip_list_find_custom(belle_sdp_rtcp_xr_attribute_get_stat_summary_flags(lAttribute), (belle_sip_compare_func)strcasecmp, "jitt"));
+	BC_ASSERT_PTR_NOT_NULL(belle_sip_list_find_custom(belle_sdp_rtcp_xr_attribute_get_stat_summary_flags(lAttribute), (belle_sip_compare_func)strcasecmp, "TTL"));
+	BC_ASSERT_TRUE(belle_sdp_rtcp_xr_attribute_has_voip_metrics(lAttribute) == TRUE);
 	belle_sip_object_unref(BELLE_SIP_OBJECT(lAttribute));
 }
 
@@ -159,8 +164,8 @@ static void test_bandwidth(void) {
 	lTmp = belle_sdp_bandwidth_parse(l_raw_bandwidth);
 	l_bandwidth = BELLE_SDP_BANDWIDTH(belle_sip_object_clone(BELLE_SIP_OBJECT(lTmp)));
 	belle_sip_object_unref(BELLE_SIP_OBJECT(lTmp));
-	CU_ASSERT_STRING_EQUAL(belle_sdp_bandwidth_get_type(l_bandwidth), "AS");
-	CU_ASSERT_EQUAL(belle_sdp_bandwidth_get_value(l_bandwidth),380);
+	BC_ASSERT_STRING_EQUAL(belle_sdp_bandwidth_get_type(l_bandwidth), "AS");
+	BC_ASSERT_EQUAL(belle_sdp_bandwidth_get_value(l_bandwidth),380, int, "%d");
 	belle_sip_object_unref(BELLE_SIP_OBJECT(l_bandwidth));
 	belle_sip_free(l_raw_bandwidth);
 }
@@ -173,9 +178,9 @@ static void test_origin(void) {
 	lTmp = belle_sdp_origin_parse(l_raw_origin);
 	lOrigin = BELLE_SDP_ORIGIN(belle_sip_object_clone(BELLE_SIP_OBJECT(lTmp)));
 	belle_sip_object_unref(BELLE_SIP_OBJECT(lTmp));
-	CU_ASSERT_STRING_EQUAL(belle_sdp_origin_get_address(lOrigin), "192.168.0.165");
-	CU_ASSERT_STRING_EQUAL(belle_sdp_origin_get_address_type(lOrigin), "IP4");
-	CU_ASSERT_STRING_EQUAL(belle_sdp_origin_get_network_type(lOrigin), "IN");
+	BC_ASSERT_STRING_EQUAL(belle_sdp_origin_get_address(lOrigin), "192.168.0.165");
+	BC_ASSERT_STRING_EQUAL(belle_sdp_origin_get_address_type(lOrigin), "IP4");
+	BC_ASSERT_STRING_EQUAL(belle_sdp_origin_get_network_type(lOrigin), "IN");
 	belle_sip_object_unref(BELLE_SIP_OBJECT(lOrigin));
 	belle_sip_free(l_raw_origin);
 }
@@ -183,7 +188,7 @@ static void test_origin(void) {
 
 static void test_malformed_origin(void) {
 	belle_sdp_origin_t* lOrigin = belle_sdp_origin_parse("o=Jehan Monnier 3800 2558 IN IP4 192.168.0.165");
-	CU_ASSERT_PTR_NULL(lOrigin);
+	BC_ASSERT_PTR_NULL(lOrigin);
 }
 
 static void test_connection(void) {
@@ -194,11 +199,11 @@ static void test_connection(void) {
 	lTmp = belle_sdp_connection_parse(l_raw_connection);
 	lConnection = BELLE_SDP_CONNECTION(belle_sip_object_clone(BELLE_SIP_OBJECT(lTmp)));
 	belle_sip_object_unref(BELLE_SIP_OBJECT(lTmp));
-	CU_ASSERT_STRING_EQUAL(belle_sdp_connection_get_address(lConnection), "192.168.0.18");
-	CU_ASSERT_STRING_EQUAL(belle_sdp_connection_get_address_type(lConnection), "IP4");
-	CU_ASSERT_STRING_EQUAL(belle_sdp_connection_get_network_type(lConnection), "IN");
-	CU_ASSERT_EQUAL(belle_sdp_connection_get_ttl(lConnection), 0);
-	CU_ASSERT_EQUAL(belle_sdp_connection_get_ttl(lConnection), 0);
+	BC_ASSERT_STRING_EQUAL(belle_sdp_connection_get_address(lConnection), "192.168.0.18");
+	BC_ASSERT_STRING_EQUAL(belle_sdp_connection_get_address_type(lConnection), "IP4");
+	BC_ASSERT_STRING_EQUAL(belle_sdp_connection_get_network_type(lConnection), "IN");
+	BC_ASSERT_EQUAL(belle_sdp_connection_get_ttl(lConnection), 0, int, "%d");
+	BC_ASSERT_EQUAL(belle_sdp_connection_get_ttl(lConnection), 0, int, "%d");
 	belle_sip_object_unref(BELLE_SIP_OBJECT(lConnection));
 	belle_sip_free(l_raw_connection);
 }
@@ -211,9 +216,9 @@ static void test_connection_6(void) {
 	lTmp = belle_sdp_connection_parse(l_raw_connection);
 	lConnection = BELLE_SDP_CONNECTION(belle_sip_object_clone(BELLE_SIP_OBJECT(lTmp)));
 	belle_sip_object_unref(BELLE_SIP_OBJECT(lTmp));
-	CU_ASSERT_STRING_EQUAL(belle_sdp_connection_get_address(lConnection), "2a01:e35:1387:1020:6233:4bff:fe0b:5663");
-	CU_ASSERT_STRING_EQUAL(belle_sdp_connection_get_address_type(lConnection), "IP6");
-	CU_ASSERT_STRING_EQUAL(belle_sdp_connection_get_network_type(lConnection), "IN");
+	BC_ASSERT_STRING_EQUAL(belle_sdp_connection_get_address(lConnection), "2a01:e35:1387:1020:6233:4bff:fe0b:5663");
+	BC_ASSERT_STRING_EQUAL(belle_sdp_connection_get_address_type(lConnection), "IP6");
+	BC_ASSERT_STRING_EQUAL(belle_sdp_connection_get_network_type(lConnection), "IN");
 	belle_sip_object_unref(BELLE_SIP_OBJECT(lConnection));
 	belle_sip_free(l_raw_connection);
 }
@@ -226,11 +231,11 @@ static void test_connection_multicast(void) {
 	lTmp = belle_sdp_connection_parse(l_raw_connection);
 	lConnection = BELLE_SDP_CONNECTION(belle_sip_object_clone(BELLE_SIP_OBJECT(lTmp)));
 	belle_sip_object_unref(BELLE_SIP_OBJECT(lTmp));
-	CU_ASSERT_STRING_EQUAL(belle_sdp_connection_get_address(lConnection), "224.2.1.1");
-	CU_ASSERT_STRING_EQUAL(belle_sdp_connection_get_address_type(lConnection), "IP4");
-	CU_ASSERT_STRING_EQUAL(belle_sdp_connection_get_network_type(lConnection), "IN");
-	CU_ASSERT_EQUAL(belle_sdp_connection_get_ttl(lConnection), 127);
-	CU_ASSERT_EQUAL(belle_sdp_connection_get_range(lConnection), 3);
+	BC_ASSERT_STRING_EQUAL(belle_sdp_connection_get_address(lConnection), "224.2.1.1");
+	BC_ASSERT_STRING_EQUAL(belle_sdp_connection_get_address_type(lConnection), "IP4");
+	BC_ASSERT_STRING_EQUAL(belle_sdp_connection_get_network_type(lConnection), "IN");
+	BC_ASSERT_EQUAL(belle_sdp_connection_get_ttl(lConnection), 127, int, "%d");
+	BC_ASSERT_EQUAL(belle_sdp_connection_get_range(lConnection), 3, int, "%d");
 	belle_sip_object_unref(BELLE_SIP_OBJECT(lConnection));
 	belle_sip_free(l_raw_connection);
 
@@ -240,11 +245,11 @@ static void test_connection_multicast(void) {
 	lTmp = belle_sdp_connection_parse(l_raw_connection);
 	lConnection = BELLE_SDP_CONNECTION(belle_sip_object_clone(BELLE_SIP_OBJECT(lTmp)));
 	belle_sip_object_unref(BELLE_SIP_OBJECT(lTmp));
-	CU_ASSERT_STRING_EQUAL(belle_sdp_connection_get_address(lConnection), "224.2.1.1");
-	CU_ASSERT_STRING_EQUAL(belle_sdp_connection_get_address_type(lConnection), "IP4");
-	CU_ASSERT_STRING_EQUAL(belle_sdp_connection_get_network_type(lConnection), "IN");
-	CU_ASSERT_EQUAL(belle_sdp_connection_get_ttl(lConnection), 127);
-	CU_ASSERT_EQUAL(belle_sdp_connection_get_range(lConnection), 0);
+	BC_ASSERT_STRING_EQUAL(belle_sdp_connection_get_address(lConnection), "224.2.1.1");
+	BC_ASSERT_STRING_EQUAL(belle_sdp_connection_get_address_type(lConnection), "IP4");
+	BC_ASSERT_STRING_EQUAL(belle_sdp_connection_get_network_type(lConnection), "IN");
+	BC_ASSERT_EQUAL(belle_sdp_connection_get_ttl(lConnection), 127, int, "%d");
+	BC_ASSERT_EQUAL(belle_sdp_connection_get_range(lConnection), 0, int, "%d");
 	belle_sip_object_unref(BELLE_SIP_OBJECT(lConnection));
 	belle_sip_free(l_raw_connection);
 
@@ -254,11 +259,11 @@ static void test_connection_multicast(void) {
 	lTmp = belle_sdp_connection_parse(l_raw_connection);
 	lConnection = BELLE_SDP_CONNECTION(belle_sip_object_clone(BELLE_SIP_OBJECT(lTmp)));
 	belle_sip_object_unref(BELLE_SIP_OBJECT(lTmp));
-	CU_ASSERT_STRING_EQUAL(belle_sdp_connection_get_address(lConnection), "::1");
-	CU_ASSERT_STRING_EQUAL(belle_sdp_connection_get_address_type(lConnection), "IP6");
-	CU_ASSERT_STRING_EQUAL(belle_sdp_connection_get_network_type(lConnection), "IN");
-	CU_ASSERT_EQUAL(belle_sdp_connection_get_ttl(lConnection), 0);
-	CU_ASSERT_EQUAL(belle_sdp_connection_get_range(lConnection), 3);
+	BC_ASSERT_STRING_EQUAL(belle_sdp_connection_get_address(lConnection), "::1");
+	BC_ASSERT_STRING_EQUAL(belle_sdp_connection_get_address_type(lConnection), "IP6");
+	BC_ASSERT_STRING_EQUAL(belle_sdp_connection_get_network_type(lConnection), "IN");
+	BC_ASSERT_EQUAL(belle_sdp_connection_get_ttl(lConnection), 0, int, "%d");
+	BC_ASSERT_EQUAL(belle_sdp_connection_get_range(lConnection), 3, int, "%d");
 	belle_sip_object_unref(BELLE_SIP_OBJECT(lConnection));
 	belle_sip_free(l_raw_connection);
 
@@ -273,7 +278,7 @@ static void test_email(void) {
 	lTmp = belle_sdp_email_parse(l_raw_email);
 	l_email = BELLE_SDP_EMAIL(belle_sip_object_clone(BELLE_SIP_OBJECT(lTmp)));
 	belle_sip_object_unref(BELLE_SIP_OBJECT(lTmp));
-	CU_ASSERT_STRING_EQUAL(belle_sdp_email_get_value(l_email), " jehan <jehan@linphone.org>");
+	BC_ASSERT_STRING_EQUAL(belle_sdp_email_get_value(l_email), " jehan <jehan@linphone.org>");
 	belle_sip_object_unref(BELLE_SIP_OBJECT(l_email));
 	belle_sip_free(l_raw_email);
 }
@@ -286,7 +291,7 @@ static void test_info(void) {
 	lTmp = belle_sdp_info_parse(l_raw_info);
 	l_info = BELLE_SDP_INFO(belle_sip_object_clone(BELLE_SIP_OBJECT(lTmp)));
 	belle_sip_object_unref(BELLE_SIP_OBJECT(lTmp));
-	CU_ASSERT_STRING_EQUAL(belle_sdp_info_get_value(l_info), "A Seminar on the session description protocol");
+	BC_ASSERT_STRING_EQUAL(belle_sdp_info_get_value(l_info), "A Seminar on the session description protocol");
 	belle_sip_object_unref(BELLE_SIP_OBJECT(l_info));
 	belle_sip_free(l_raw_info);
 }
@@ -302,13 +307,13 @@ static void test_media(void) {
 	lTmp = belle_sdp_media_parse(l_raw_media);
 	l_media = BELLE_SDP_MEDIA(belle_sip_object_clone(BELLE_SIP_OBJECT(lTmp)));
 	belle_sip_object_unref(BELLE_SIP_OBJECT(lTmp));
-	CU_ASSERT_STRING_EQUAL(belle_sdp_media_get_media_type(l_media), "audio");
-	CU_ASSERT_EQUAL(belle_sdp_media_get_media_port(l_media), 7078);
-	CU_ASSERT_STRING_EQUAL(belle_sdp_media_get_protocol(l_media), "RTP/AVP");
+	BC_ASSERT_STRING_EQUAL(belle_sdp_media_get_media_type(l_media), "audio");
+	BC_ASSERT_EQUAL(belle_sdp_media_get_media_port(l_media), 7078, int, "%d");
+	BC_ASSERT_STRING_EQUAL(belle_sdp_media_get_protocol(l_media), "RTP/AVP");
 	list = belle_sdp_media_get_media_formats(l_media);
-	CU_ASSERT_PTR_NOT_NULL(list);
+	BC_ASSERT_PTR_NOT_NULL(list);
 	for(;list!=NULL;list=list->next){
-		CU_ASSERT_EQUAL(BELLE_SIP_POINTER_TO_INT(list->data),fmt[i++]);
+		BC_ASSERT_EQUAL(BELLE_SIP_POINTER_TO_INT(list->data),fmt[i++], int, "%d");
 	}
 
 	belle_sip_object_unref(BELLE_SIP_OBJECT(l_media));
@@ -327,31 +332,31 @@ static void test_media_description_base(belle_sdp_media_description_t* media_des
 	belle_sip_list_t* list;
 	int fmt[] ={99,97,98};
 	int i=0;
-	CU_ASSERT_PTR_NOT_NULL(l_media);
-	CU_ASSERT_STRING_EQUAL(belle_sdp_media_get_media_type(l_media), "video");
-	CU_ASSERT_EQUAL(belle_sdp_media_get_media_port(l_media), 8078);
-	CU_ASSERT_STRING_EQUAL(belle_sdp_media_get_protocol(l_media), "RTP/AVP");
+	BC_ASSERT_PTR_NOT_NULL(l_media);
+	BC_ASSERT_STRING_EQUAL(belle_sdp_media_get_media_type(l_media), "video");
+	BC_ASSERT_EQUAL(belle_sdp_media_get_media_port(l_media), 8078, int, "%d");
+	BC_ASSERT_STRING_EQUAL(belle_sdp_media_get_protocol(l_media), "RTP/AVP");
 	list = belle_sdp_media_get_media_formats(l_media);
-	CU_ASSERT_PTR_NOT_NULL(list);
+	BC_ASSERT_PTR_NOT_NULL(list);
 	for(;list!=NULL;list=list->next){
-		CU_ASSERT_EQUAL(BELLE_SIP_POINTER_TO_INT(list->data),fmt[i++]);
+		BC_ASSERT_EQUAL(BELLE_SIP_POINTER_TO_INT(list->data),fmt[i++], int, "%d");
 	}
 	/*connection*/
 	lConnection = belle_sdp_media_description_get_connection(l_media_description);
-	CU_ASSERT_STRING_EQUAL(belle_sdp_connection_get_address(lConnection), "192.168.0.18");
-	CU_ASSERT_STRING_EQUAL(belle_sdp_connection_get_address_type(lConnection), "IP4");
-	CU_ASSERT_STRING_EQUAL(belle_sdp_connection_get_network_type(lConnection), "IN");
+	BC_ASSERT_STRING_EQUAL(belle_sdp_connection_get_address(lConnection), "192.168.0.18");
+	BC_ASSERT_STRING_EQUAL(belle_sdp_connection_get_address_type(lConnection), "IP4");
+	BC_ASSERT_STRING_EQUAL(belle_sdp_connection_get_network_type(lConnection), "IN");
 
 	/*bandwidth*/
 
-	CU_ASSERT_EQUAL(belle_sdp_media_description_get_bandwidth(l_media_description,"AS"),380);
+	BC_ASSERT_EQUAL(belle_sdp_media_description_get_bandwidth(l_media_description,"AS"),380, int, "%d");
 
 	/*attributes*/
 	list = belle_sdp_media_description_get_attributes(l_media_description);
-	CU_ASSERT_PTR_NOT_NULL(list);
+	BC_ASSERT_PTR_NOT_NULL(list);
 	i=0;
 	for(;list!=NULL;list=list->next){
-		CU_ASSERT_STRING_EQUAL(belle_sdp_attribute_get_value((belle_sdp_attribute_t*)(list->data)),attr[i++]);
+		BC_ASSERT_STRING_EQUAL(belle_sdp_attribute_get_value((belle_sdp_attribute_t*)(list->data)),attr[i++]);
 	}
 
 }
@@ -381,11 +386,12 @@ static void test_media_description(void) {
 
 static void test_simple_session_description(void) {
 	const char* l_src = "v=0\r\n"\
-						"o=jehan-mac 1239 1239 IN IP4 192.168.0.18\r\n"\
+						"o=jehan-mac 2463217870 2463217870 IN IP4 192.168.0.18\r\n"\
 						"s=Talk\r\n"\
 						"c=IN IP4 192.168.0.18\r\n"\
 						"t=0 0\r\n"\
 						"m=audio 7078 RTP/AVP 111 110 3 0 8 101\r\n"\
+						"a=alt:1 1 : e2br+9PL Eu1qGlQ9 10.211.55.3 8988\r\n"\
 						"a=rtpmap:111 speex/16000\r\n"\
 						"a=fmtp:111 vbr=on\r\n"\
 						"a=rtpmap:110 speex/8000\r\n"\
@@ -411,37 +417,37 @@ static void test_simple_session_description(void) {
 	l_session_description = BELLE_SDP_SESSION_DESCRIPTION(belle_sip_object_clone(BELLE_SIP_OBJECT(lTmp)));
 	belle_sip_object_unref(BELLE_SIP_OBJECT(lTmp));
 
-	CU_ASSERT_PTR_NOT_NULL(belle_sdp_session_description_get_version(l_session_description));
-	CU_ASSERT_EQUAL(belle_sdp_version_get_version(belle_sdp_session_description_get_version(l_session_description)),0);
+	BC_ASSERT_PTR_NOT_NULL(belle_sdp_session_description_get_version(l_session_description));
+	BC_ASSERT_EQUAL(belle_sdp_version_get_version(belle_sdp_session_description_get_version(l_session_description)),0, int, "%d");
 
 	l_origin = belle_sdp_session_description_get_origin(l_session_description);
-	CU_ASSERT_PTR_NOT_NULL(l_origin);
-	CU_ASSERT_STRING_EQUAL(belle_sdp_origin_get_address(l_origin),"192.168.0.18")
-	CU_ASSERT_STRING_EQUAL(belle_sdp_origin_get_address_type(l_origin),"IP4")
-	CU_ASSERT_STRING_EQUAL(belle_sdp_origin_get_network_type(l_origin),"IN")
-	CU_ASSERT_EQUAL(belle_sdp_origin_get_session_id(l_origin),1239)
-	CU_ASSERT_EQUAL(belle_sdp_origin_get_session_version(l_origin),1239)
+	BC_ASSERT_PTR_NOT_NULL(l_origin);
+	BC_ASSERT_STRING_EQUAL(belle_sdp_origin_get_address(l_origin),"192.168.0.18");
+	BC_ASSERT_STRING_EQUAL(belle_sdp_origin_get_address_type(l_origin),"IP4");
+	BC_ASSERT_STRING_EQUAL(belle_sdp_origin_get_network_type(l_origin),"IN");
+	BC_ASSERT_EQUAL(belle_sdp_origin_get_session_id(l_origin), 2463217870U, unsigned, "%u");
+	BC_ASSERT_EQUAL(belle_sdp_origin_get_session_version(l_origin), 2463217870U, unsigned, "%u");
 
-	CU_ASSERT_PTR_NOT_NULL(belle_sdp_session_description_get_session_name(l_session_description));
-	CU_ASSERT_STRING_EQUAL(belle_sdp_session_name_get_value(belle_sdp_session_description_get_session_name(l_session_description)),"Talk");
+	BC_ASSERT_PTR_NOT_NULL(belle_sdp_session_description_get_session_name(l_session_description));
+	BC_ASSERT_STRING_EQUAL(belle_sdp_session_name_get_value(belle_sdp_session_description_get_session_name(l_session_description)),"Talk");
 
-	CU_ASSERT_PTR_NOT_NULL(belle_sdp_session_description_get_connection(l_session_description));
-	CU_ASSERT_PTR_NOT_NULL(belle_sdp_session_description_get_time_descriptions(l_session_description));
-	CU_ASSERT_EQUAL(belle_sdp_time_get_start(belle_sdp_time_description_get_time((belle_sdp_time_description_t*)(belle_sdp_session_description_get_time_descriptions(l_session_description)->data))),0);
-	CU_ASSERT_EQUAL(belle_sdp_time_get_stop(belle_sdp_time_description_get_time((belle_sdp_time_description_t*)(belle_sdp_session_description_get_time_descriptions(l_session_description)->data))),0);
+	BC_ASSERT_PTR_NOT_NULL(belle_sdp_session_description_get_connection(l_session_description));
+	BC_ASSERT_PTR_NOT_NULL(belle_sdp_session_description_get_time_descriptions(l_session_description));
+	BC_ASSERT_EQUAL(belle_sdp_time_get_start(belle_sdp_time_description_get_time((belle_sdp_time_description_t*)(belle_sdp_session_description_get_time_descriptions(l_session_description)->data))),0, int, "%d");
+	BC_ASSERT_EQUAL(belle_sdp_time_get_stop(belle_sdp_time_description_get_time((belle_sdp_time_description_t*)(belle_sdp_session_description_get_time_descriptions(l_session_description)->data))),0, int, "%d");
 
 	media_descriptions = belle_sdp_session_description_get_media_descriptions(l_session_description);
-	CU_ASSERT_PTR_NOT_NULL(media_descriptions);
-	CU_ASSERT_STRING_EQUAL (belle_sdp_media_get_media_type(belle_sdp_media_description_get_media((belle_sdp_media_description_t*)(media_descriptions->data))),"audio");
+	BC_ASSERT_PTR_NOT_NULL(media_descriptions);
+	BC_ASSERT_STRING_EQUAL (belle_sdp_media_get_media_type(belle_sdp_media_description_get_media((belle_sdp_media_description_t*)(media_descriptions->data))),"audio");
 	media_descriptions=media_descriptions->next;
-	CU_ASSERT_PTR_NOT_NULL(media_descriptions);
+	BC_ASSERT_PTR_NOT_NULL(media_descriptions);
 
 	test_media_description_base((belle_sdp_media_description_t*)(media_descriptions->data));
 	belle_sip_object_unref(l_session_description);
 	return;
 }
 
-static void test_image_mline() {
+static void test_image_mline(void) {
 	const char * sdp =	"v=0\r\n"
 						"o=cp10 138884701697 138884701699 IN IP4 10.7.1.133\r\n"
 						"s=SIP Call\r\n"
@@ -495,30 +501,30 @@ static void test_session_description(void) {
 	l_session_description = BELLE_SDP_SESSION_DESCRIPTION(belle_sip_object_clone(BELLE_SIP_OBJECT(lTmp)));
 	belle_sip_object_unref(BELLE_SIP_OBJECT(lTmp));
 
-	CU_ASSERT_PTR_NOT_NULL(belle_sdp_session_description_get_version(l_session_description));
-	CU_ASSERT_EQUAL(belle_sdp_version_get_version(belle_sdp_session_description_get_version(l_session_description)),0);
+	BC_ASSERT_PTR_NOT_NULL(belle_sdp_session_description_get_version(l_session_description));
+	BC_ASSERT_EQUAL(belle_sdp_version_get_version(belle_sdp_session_description_get_version(l_session_description)),0, int, "%d");
 
 	l_origin = belle_sdp_session_description_get_origin(l_session_description);
-	CU_ASSERT_PTR_NOT_NULL(l_origin);
-	CU_ASSERT_STRING_EQUAL(belle_sdp_origin_get_address(l_origin),"2a01:e35:1387:1020:6233:4bff:fe0b:5663")
-	CU_ASSERT_STRING_EQUAL(belle_sdp_origin_get_address_type(l_origin),"IP6")
-	CU_ASSERT_STRING_EQUAL(belle_sdp_origin_get_network_type(l_origin),"IN")
-	CU_ASSERT_EQUAL(belle_sdp_origin_get_session_id(l_origin),1239)
-	CU_ASSERT_EQUAL(belle_sdp_origin_get_session_version(l_origin),1239)
+	BC_ASSERT_PTR_NOT_NULL(l_origin);
+	BC_ASSERT_STRING_EQUAL(belle_sdp_origin_get_address(l_origin),"2a01:e35:1387:1020:6233:4bff:fe0b:5663");
+	BC_ASSERT_STRING_EQUAL(belle_sdp_origin_get_address_type(l_origin),"IP6");
+	BC_ASSERT_STRING_EQUAL(belle_sdp_origin_get_network_type(l_origin),"IN");
+	BC_ASSERT_EQUAL(belle_sdp_origin_get_session_id(l_origin),1239, unsigned, "%u");
+	BC_ASSERT_EQUAL(belle_sdp_origin_get_session_version(l_origin),1239, unsigned, "%u");
 
-	CU_ASSERT_PTR_NOT_NULL(belle_sdp_session_description_get_session_name(l_session_description));
-	CU_ASSERT_STRING_EQUAL(belle_sdp_session_name_get_value(belle_sdp_session_description_get_session_name(l_session_description)),"SIP Talk");
+	BC_ASSERT_PTR_NOT_NULL(belle_sdp_session_description_get_session_name(l_session_description));
+	BC_ASSERT_STRING_EQUAL(belle_sdp_session_name_get_value(belle_sdp_session_description_get_session_name(l_session_description)),"SIP Talk");
 
-	CU_ASSERT_PTR_NOT_NULL(belle_sdp_session_description_get_connection(l_session_description));
-	CU_ASSERT_PTR_NOT_NULL(belle_sdp_session_description_get_time_descriptions(l_session_description));
-	CU_ASSERT_EQUAL(belle_sdp_time_get_start(belle_sdp_time_description_get_time((belle_sdp_time_description_t*)(belle_sdp_session_description_get_time_descriptions(l_session_description)->data))),0);
-	CU_ASSERT_EQUAL(belle_sdp_time_get_stop(belle_sdp_time_description_get_time((belle_sdp_time_description_t*)(belle_sdp_session_description_get_time_descriptions(l_session_description)->data))),0);
+	BC_ASSERT_PTR_NOT_NULL(belle_sdp_session_description_get_connection(l_session_description));
+	BC_ASSERT_PTR_NOT_NULL(belle_sdp_session_description_get_time_descriptions(l_session_description));
+	BC_ASSERT_EQUAL(belle_sdp_time_get_start(belle_sdp_time_description_get_time((belle_sdp_time_description_t*)(belle_sdp_session_description_get_time_descriptions(l_session_description)->data))),0, int, "%d");
+	BC_ASSERT_EQUAL(belle_sdp_time_get_stop(belle_sdp_time_description_get_time((belle_sdp_time_description_t*)(belle_sdp_session_description_get_time_descriptions(l_session_description)->data))),0, int, "%d");
 
 	media_descriptions = belle_sdp_session_description_get_media_descriptions(l_session_description);
-	CU_ASSERT_PTR_NOT_NULL(media_descriptions);
-	CU_ASSERT_STRING_EQUAL (belle_sdp_media_get_media_type(belle_sdp_media_description_get_media((belle_sdp_media_description_t*)(media_descriptions->data))),"audio");
+	BC_ASSERT_PTR_NOT_NULL(media_descriptions);
+	BC_ASSERT_STRING_EQUAL (belle_sdp_media_get_media_type(belle_sdp_media_description_get_media((belle_sdp_media_description_t*)(media_descriptions->data))),"audio");
 	media_descriptions=media_descriptions->next;
-	CU_ASSERT_PTR_NOT_NULL(media_descriptions);
+	BC_ASSERT_PTR_NOT_NULL(media_descriptions);
 
 	test_media_description_base((belle_sdp_media_description_t*)(media_descriptions->data));
 	belle_sip_object_unref(l_session_description);
@@ -534,20 +540,20 @@ static void test_overflow(void){
 	size_t buffsize=orig_buffsize;
 	char *buffer=belle_sip_malloc0(buffsize);
 	size_t offset=0;
-	
+
 	sdp=belle_sdp_session_description_parse(big_sdp);
-	CU_ASSERT_PTR_NOT_NULL(sdp);
+	BC_ASSERT_PTR_NOT_NULL(sdp);
 	mds=belle_sdp_session_description_get_media_descriptions(sdp);
-	CU_ASSERT_PTR_NOT_NULL(mds);
-	CU_ASSERT_PTR_NOT_NULL(mds->next);
+	BC_ASSERT_PTR_NOT_NULL(mds);
+	BC_ASSERT_PTR_NOT_NULL(mds->next);
 	vmd=(belle_sdp_media_description_t*)mds->next->data;
 	for(i=0;i<16;i++){
 		belle_sdp_media_description_add_attribute(vmd,belle_sdp_attribute_create("candidate","2 1 UDP 1694498815 82.65.223.97 9078 typ srflx raddr 192.168.0.2 rport 9078"));
 	}
 
-	CU_ASSERT_EQUAL(belle_sip_object_marshal(BELLE_SIP_OBJECT(sdp),buffer,buffsize,&offset),BELLE_SIP_BUFFER_OVERFLOW);
+	BC_ASSERT_EQUAL(belle_sip_object_marshal(BELLE_SIP_OBJECT(sdp),buffer,buffsize,&offset),BELLE_SIP_BUFFER_OVERFLOW, int, "%d");
 	belle_sip_message("marshal size is %i",(int)offset);
-	CU_ASSERT_TRUE(offset==buffsize);
+	BC_ASSERT_TRUE(offset==buffsize);
 	belle_sip_object_unref(sdp);
 	belle_sip_free(buffer);
 }
@@ -569,14 +575,14 @@ static void check_mime_param (belle_sdp_mime_parameter_t* mime_param
 							,int media_format
 							,const char* type
 							,const char* parameters) {
-	CU_ASSERT_PTR_NOT_NULL(mime_param);
-	CU_ASSERT_EQUAL(belle_sdp_mime_parameter_get_rate(mime_param),rate);
-	CU_ASSERT_EQUAL(belle_sdp_mime_parameter_get_channel_count(mime_param),channel_count);
-	CU_ASSERT_EQUAL(belle_sdp_mime_parameter_get_ptime(mime_param),ptime);
-	CU_ASSERT_EQUAL(belle_sdp_mime_parameter_get_max_ptime(mime_param),max_ptime);
-	CU_ASSERT_EQUAL(belle_sdp_mime_parameter_get_media_format(mime_param),media_format);
-	if (type) CU_ASSERT_STRING_EQUAL(belle_sdp_mime_parameter_get_type(mime_param),type);
-	if (parameters) CU_ASSERT_STRING_EQUAL(belle_sdp_mime_parameter_get_parameters(mime_param),parameters);
+	BC_ASSERT_PTR_NOT_NULL(mime_param);
+	BC_ASSERT_EQUAL(belle_sdp_mime_parameter_get_rate(mime_param),rate, int, "%d");
+	BC_ASSERT_EQUAL(belle_sdp_mime_parameter_get_channel_count(mime_param),channel_count, int, "%d");
+	BC_ASSERT_EQUAL(belle_sdp_mime_parameter_get_ptime(mime_param),ptime, int, "%d");
+	BC_ASSERT_EQUAL(belle_sdp_mime_parameter_get_max_ptime(mime_param),max_ptime, int, "%d");
+	BC_ASSERT_EQUAL(belle_sdp_mime_parameter_get_media_format(mime_param),media_format, int, "%d");
+	if (type) BC_ASSERT_STRING_EQUAL(belle_sdp_mime_parameter_get_type(mime_param),type);
+	if (parameters) BC_ASSERT_STRING_EQUAL(belle_sdp_mime_parameter_get_parameters(mime_param),parameters);
 }
 int static compare_attribute(belle_sdp_attribute_t* attr, const char* value) {
 	return strcasecmp(belle_sdp_attribute_get_name(attr),"rtpmap")==0
@@ -605,7 +611,7 @@ static void test_mime_parameter(void) {
 
 	mime_parameter_list = belle_sdp_media_description_build_mime_parameters(l_media_description);
 	mime_parameter_list_iterator = mime_parameter_list;
-	CU_ASSERT_PTR_NOT_NULL(mime_parameter_list);
+	BC_ASSERT_PTR_NOT_NULL(mime_parameter_list);
 	belle_sip_object_unref(BELLE_SIP_OBJECT(l_media_description));
 
 	l_media_description = belle_sdp_media_description_new();
@@ -627,11 +633,11 @@ static void test_mime_parameter(void) {
 	{
 		belle_sip_list_t* attributes=belle_sdp_media_description_get_attributes(l_media_description);
 #ifdef	BELLE_SDP_FORCE_RTP_MAP
-		CU_ASSERT_PTR_NOT_NULL(belle_sip_list_find_custom(attributes,(belle_sip_compare_func)compare_attribute,"8 PCMA/8000"));
-		CU_ASSERT_PTR_NOT_NULL(belle_sip_list_find_custom(attributes,(belle_sip_compare_func)compare_attribute,"18 G729/8000"));
+		BC_ASSERT_PTR_NOT_NULL(belle_sip_list_find_custom(attributes,(belle_sip_compare_func)compare_attribute,"8 PCMA/8000"));
+		BC_ASSERT_PTR_NOT_NULL(belle_sip_list_find_custom(attributes,(belle_sip_compare_func)compare_attribute,"18 G729/8000"));
 #else
-		CU_ASSERT_PTR_NOT_NULL(belle_sip_list_find_custom(attributes,(belle_sip_compare_func)compare_attribute,"8 PCMA/8000"));
-		CU_ASSERT_PTR_NOT_NULL(belle_sip_list_find_custom(attributes,(belle_sip_compare_func)compare_attribute,"18 G729/8000"));
+		BC_ASSERT_PTR_NOT_NULL(belle_sip_list_find_custom(attributes,(belle_sip_compare_func)compare_attribute,"8 PCMA/8000"));
+		BC_ASSERT_PTR_NOT_NULL(belle_sip_list_find_custom(attributes,(belle_sip_compare_func)compare_attribute,"18 G729/8000"));
 #endif
 	}
 	mime_parameter_list = belle_sdp_media_description_build_mime_parameters(l_media_description);
@@ -639,36 +645,36 @@ static void test_mime_parameter(void) {
 	lTmp = find_mime_parameter(mime_parameter_list,111);
 	l_param = BELLE_SDP_MIME_PARAMETER(belle_sip_object_clone(BELLE_SIP_OBJECT(lTmp)));
 
-	CU_ASSERT_PTR_NOT_NULL(l_param);
+	BC_ASSERT_PTR_NOT_NULL(l_param);
 	check_mime_param(l_param,16000,1,40,-1,111,"speex","vbr=on");
 	belle_sip_object_unref(l_param);
 
 	l_param = find_mime_parameter(mime_parameter_list,110);
-	CU_ASSERT_PTR_NOT_NULL(l_param);
+	BC_ASSERT_PTR_NOT_NULL(l_param);
 	check_mime_param(l_param,8000,1,40,-1,110,"speex","vbr=on");
 
 	l_param = find_mime_parameter(mime_parameter_list,3);
-	CU_ASSERT_PTR_NOT_NULL(l_param);
+	BC_ASSERT_PTR_NOT_NULL(l_param);
 	check_mime_param(l_param,8000,1,40,-1,3,"GSM",NULL);
 
 
 	l_param = find_mime_parameter(mime_parameter_list,0);
-	CU_ASSERT_PTR_NOT_NULL(l_param);
+	BC_ASSERT_PTR_NOT_NULL(l_param);
 	check_mime_param(l_param,8000,1,40,-1,0,"PCMU",NULL);
 
 
 	l_param = find_mime_parameter(mime_parameter_list,8);
-	CU_ASSERT_PTR_NOT_NULL(l_param);
+	BC_ASSERT_PTR_NOT_NULL(l_param);
 	check_mime_param(l_param,8000,1,40,-1,8,"PCMA",NULL);
 
 
 	l_param = find_mime_parameter(mime_parameter_list,9);
-	CU_ASSERT_PTR_NOT_NULL(l_param);
+	BC_ASSERT_PTR_NOT_NULL(l_param);
 	check_mime_param(l_param,8000,1,40,-1,9,"G722",NULL);
 
 
 	l_param = find_mime_parameter(mime_parameter_list,101);
-	CU_ASSERT_PTR_NOT_NULL(l_param);
+	BC_ASSERT_PTR_NOT_NULL(l_param);
 	check_mime_param(l_param,8000,1,40,-1,101,"telephone-event","0-11");
 
 	belle_sip_list_free_with_data(mime_parameter_list, (void (*)(void*))belle_sip_object_unref);
@@ -697,11 +703,5 @@ test_t sdp_tests[] = {
 	{ "Marshal buffer overflow", test_overflow }
 };
 
-test_suite_t sdp_test_suite = {
-	"SDP",
-	NULL,
-	NULL,
-	sizeof(sdp_tests) / sizeof(sdp_tests[0]),
-	sdp_tests
-};
-
+test_suite_t sdp_test_suite = {"SDP", NULL, NULL, belle_sip_tester_before_each, belle_sip_tester_after_each,
+							   sizeof(sdp_tests) / sizeof(sdp_tests[0]), sdp_tests};
