@@ -16,8 +16,6 @@
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include <stdio.h>
-#include "CUnit/Basic.h"
 #include "belle-sip/belle-sip.h"
 #include "belle_sip_tester.h"
 
@@ -110,10 +108,10 @@ static void caller_process_request_event(void *user_ctx, const belle_sip_request
 	}
 	belle_sip_message("caller_process_request_event received [%s] message",belle_sip_request_get_method(belle_sip_request_event_get_request(event)));
 	server_transaction=belle_sip_provider_create_server_transaction(prov,belle_sip_request_event_get_request(event));
-	CU_ASSERT_STRING_EQUAL_FATAL("BYE",belle_sip_request_get_method(belle_sip_request_event_get_request(event)));
+	BC_ASSERT_STRING_EQUAL_FATAL("BYE",belle_sip_request_get_method(belle_sip_request_event_get_request(event)));
 	dialog =  belle_sip_transaction_get_dialog(BELLE_SIP_TRANSACTION(server_transaction));
-	CU_ASSERT_PTR_NOT_NULL_FATAL(dialog);
-	CU_ASSERT_EQUAL(belle_sip_dialog_get_state(dialog) , BELLE_SIP_DIALOG_CONFIRMED);
+	BC_ASSERT_PTR_NOT_NULL_FATAL(dialog);
+	BC_ASSERT_EQUAL(belle_sip_dialog_get_state(dialog) , BELLE_SIP_DIALOG_CONFIRMED, int, "%d");
 	resp=belle_sip_response_create_from_request(belle_sip_request_event_get_request(event),200);
 	belle_sip_server_transaction_send_response(server_transaction,resp);
 
@@ -135,11 +133,11 @@ static void callee_process_request_event(void *user_ctx, const belle_sip_request
 	if (!server_transaction && strcmp(method,"ACK")!=0) {
 		server_transaction= belle_sip_provider_create_server_transaction(prov,belle_sip_request_event_get_request(event));
 	}
-	
+
 	belle_sip_message("callee_process_request_event received [%s] message",method);
 	dialog = belle_sip_request_event_get_dialog(event);
 	if (!dialog ) {
-		CU_ASSERT_STRING_EQUAL_FATAL("INVITE",method);
+		BC_ASSERT_STRING_EQUAL_FATAL("INVITE",method);
 		dialog=belle_sip_provider_create_dialog(prov,BELLE_SIP_TRANSACTION(server_transaction));
 		callee_dialog=dialog;
 		inserv_transaction=server_transaction;
@@ -180,14 +178,14 @@ static void caller_process_response_event(void *user_ctx, const belle_sip_respon
 
 	status = belle_sip_response_get_status_code(belle_sip_response_event_get_response(event));
 	belle_sip_message("caller_process_response_event [%i]",status);
-	CU_ASSERT_PTR_NOT_NULL_FATAL(client_transaction);
+	BC_ASSERT_PTR_NOT_NULL_FATAL(client_transaction);
 	dialog = belle_sip_transaction_get_dialog(BELLE_SIP_TRANSACTION(client_transaction));
-	CU_ASSERT_PTR_NOT_NULL_FATAL(dialog);
-	CU_ASSERT_PTR_EQUAL(caller_dialog,dialog);
+	BC_ASSERT_PTR_NOT_NULL_FATAL(dialog);
+	BC_ASSERT_PTR_EQUAL(caller_dialog,dialog);
 	if (belle_sip_dialog_get_state(dialog) == BELLE_SIP_DIALOG_NULL) {
-		CU_ASSERT_EQUAL(status,100);
+		BC_ASSERT_EQUAL(status,100, int, "%d");
 	} else if (belle_sip_dialog_get_state(dialog) == BELLE_SIP_DIALOG_EARLY){
-		CU_ASSERT_EQUAL(status,180);
+		BC_ASSERT_EQUAL(status,180, int, "%d");
 		/*send 200ok from callee*/
 		belle_sip_server_transaction_send_response(inserv_transaction,ok_response);
 		belle_sip_object_unref(ok_response);
@@ -210,10 +208,10 @@ static void callee_process_response_event(void *user_ctx, const belle_sip_respon
 		belle_sip_message("Message [%p] not for callee, skipping",belle_sip_response_event_get_response(event));
 		return; /*not for the callee*/
 	}
-	CU_ASSERT_PTR_NOT_NULL_FATAL(client_transaction);
+	BC_ASSERT_PTR_NOT_NULL_FATAL(client_transaction);
 	dialog = belle_sip_transaction_get_dialog(BELLE_SIP_TRANSACTION(client_transaction));
-	CU_ASSERT_PTR_NOT_NULL_FATAL(dialog);
-	CU_ASSERT_PTR_EQUAL(callee_dialog,dialog);
+	BC_ASSERT_PTR_NOT_NULL_FATAL(dialog);
+	BC_ASSERT_PTR_EQUAL(callee_dialog,dialog);
 	if (belle_sip_dialog_get_state(dialog) == BELLE_SIP_DIALOG_TERMINATED) {
 		call_endeed=1;
 		belle_sip_main_loop_quit(belle_sip_stack_get_main_loop(stack));
@@ -319,7 +317,7 @@ static void do_simple_call(void) {
 
 	client_transaction = belle_sip_provider_create_client_transaction(prov,req);
 	caller_dialog=belle_sip_provider_create_dialog(prov,BELLE_SIP_TRANSACTION(client_transaction));
-	CU_ASSERT_PTR_NOT_NULL_FATAL(belle_sip_transaction_get_dialog(BELLE_SIP_TRANSACTION(client_transaction)));
+	BC_ASSERT_PTR_NOT_NULL_FATAL(belle_sip_transaction_get_dialog(BELLE_SIP_TRANSACTION(client_transaction)));
 	//belle_sip_transaction_set_application_data(BELLE_SIP_TRANSACTION(client_transaction),op);
 	call_endeed=0;
 	belle_sip_client_transaction_send_request(client_transaction);
@@ -327,7 +325,7 @@ static void do_simple_call(void) {
 	//for(i=0;i<10 &&!call_endeed;i++)
 	belle_sip_stack_sleep(stack,30000);
 
-	CU_ASSERT_EQUAL(call_endeed,1);
+	BC_ASSERT_EQUAL(call_endeed,1, int, "%d");
 
 	belle_sip_provider_remove_sip_listener(prov,caller_listener);
 	belle_sip_provider_remove_sip_listener(prov,callee_listener);
@@ -367,11 +365,6 @@ test_t dialog_tests[] = {
 	{ "Simple call with delay", simple_call_with_delay }
 };
 
-test_suite_t dialog_test_suite = {
-	"Dialog",
-	register_init,
-	register_uninit,
-	sizeof(dialog_tests) / sizeof(dialog_tests[0]),
-	dialog_tests
-};
-
+test_suite_t dialog_test_suite = {"Dialog", register_before_all, register_after_all, belle_sip_tester_before_each,
+								  belle_sip_tester_after_each, sizeof(dialog_tests) / sizeof(dialog_tests[0]),
+								  dialog_tests};
