@@ -16,8 +16,6 @@
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include <stdio.h>
-#include "CUnit/Basic.h"
 #include "belle-sip/belle-sip.h"
 #include "belle_sip_internal.h"
 #include "belle_sip_tester.h"
@@ -54,6 +52,7 @@ typedef struct _status {
 	int fourHundredOne;
 	int refreshOk;
 	int refreshKo;
+	int dialogTerminated;
 }status_t;
 
 typedef struct endpoint {
@@ -95,7 +94,7 @@ static unsigned int  wait_for(belle_sip_stack_t*s1, belle_sip_stack_t*s2,int* co
 //static void process_io_error(void *obj, const belle_sip_io_error_event_t *event){
 //	belle_sip_warning("process_io_error");
 //	/*belle_sip_main_loop_quit(belle_sip_stack_get_main_loop(stack));*/
-//	/*CU_ASSERT(CU_FALSE);*/
+//	/*BC_ASSERT(CU_FALSE);*/
 //}
 
 static void compute_response(const char* username
@@ -127,7 +126,7 @@ static void compute_response_auth_qop(const char* username
 	belle_sip_auth_helper_compute_response_qop_auth(ha1, nonce,nonce_count, cnonce,qop,ha2,response);
 }
 
-#define MAX_NC_COUNT 3
+#define MAX_NC_COUNT 5
 
 static void server_process_request_event(void *obj, const belle_sip_request_event_t *event){
 	endpoint_t* endpoint = (endpoint_t*)obj;
@@ -227,17 +226,23 @@ static void server_process_request_event(void *obj, const belle_sip_request_even
 
 			belle_sip_header_t* sip_if_match=belle_sip_message_get_header(BELLE_SIP_MESSAGE(resp),"SIP-If-Match");
 			if (sip_if_match) {
-				CU_ASSERT_STRING_EQUAL(belle_sip_header_extension_get_value(BELLE_SIP_HEADER_EXTENSION(sip_if_match)),"blablietag");
+				BC_ASSERT_STRING_EQUAL(belle_sip_header_extension_get_value(BELLE_SIP_HEADER_EXTENSION(sip_if_match)),"blablietag");
 			}
 			/*check for body*/
-			CU_ASSERT_PTR_NOT_NULL(belle_sip_message_get_body(BELLE_SIP_MESSAGE(req)));
+			BC_ASSERT_PTR_NOT_NULL(belle_sip_message_get_body(BELLE_SIP_MESSAGE(req)));
 			if (belle_sip_message_get_body(BELLE_SIP_MESSAGE(req))) {
-				CU_ASSERT_STRING_EQUAL(belle_sip_message_get_body(BELLE_SIP_MESSAGE(req)),publish_body);
+				BC_ASSERT_STRING_EQUAL(belle_sip_message_get_body(BELLE_SIP_MESSAGE(req)),publish_body);
 			}
-			CU_ASSERT_PTR_NOT_NULL(belle_sip_message_get_header_by_type(req,belle_sip_header_content_type_t));
-			CU_ASSERT_PTR_NOT_NULL(belle_sip_message_get_header_by_type(req,belle_sip_header_content_length_t));
+			BC_ASSERT_PTR_NOT_NULL(belle_sip_message_get_header_by_type(req,belle_sip_header_content_type_t));
+			BC_ASSERT_PTR_NOT_NULL(belle_sip_message_get_header_by_type(req,belle_sip_header_content_length_t));
 			belle_sip_message_add_header(BELLE_SIP_MESSAGE(resp),belle_sip_header_create("SIP-ETag","blablietag"));
 		}
+		if (strcmp(belle_sip_request_get_method(req),"SUBSCRIBE")==0){
+			if (belle_sip_request_event_get_dialog(event) == NULL){
+				belle_sip_message("creating dialog for incoming SUBSCRIBE");
+				belle_sip_provider_create_dialog(endpoint->provider, BELLE_SIP_TRANSACTION(server_transaction));
+			}
+		}
 	} else {
 		resp=belle_sip_response_create_from_request(belle_sip_request_event_get_request(event),401);
 		if (www_authenticate)
@@ -250,6 +255,16 @@ static void server_process_request_event(void *obj, const belle_sip_request_even
 	belle_sip_server_transaction_send_response(server_transaction,resp);
 }
 
+static void client_process_dialog_terminated(void *obj, const belle_sip_dialog_terminated_event_t *event){
+	endpoint_t* endpoint = (endpoint_t*)obj;
+	endpoint->stat.dialogTerminated++;
+}
+
+static void server_process_dialog_terminated(void *obj, const belle_sip_dialog_terminated_event_t *event){
+	endpoint_t* endpoint = (endpoint_t*)obj;
+	endpoint->stat.dialogTerminated++;
+}
+
 static void client_process_response_event(void *obj, const belle_sip_response_event_t *event){
 	//belle_sip_client_transaction_t* client_transaction = belle_sip_response_event_get_client_transaction(event);
 	endpoint_t* endpoint = (endpoint_t*)obj;
@@ -263,11 +278,11 @@ static void client_process_response_event(void *obj, const belle_sip_response_ev
 			int family_found;
 			belle_sip_header_contact_t *ct=belle_sip_message_get_header_by_type(
 				(belle_sip_message_t*)belle_sip_response_event_get_response(event),belle_sip_header_contact_t);
-			CU_ASSERT_PTR_NOT_NULL_FATAL(ct);
+			BC_ASSERT_PTR_NOT_NULL_FATAL(ct);
 			host=belle_sip_uri_get_host(belle_sip_header_address_get_uri((belle_sip_header_address_t*)ct));
 			if (strchr(host,':')) family_found=AF_INET6;
 			else family_found=AF_INET;
-			CU_ASSERT_TRUE(family_found==endpoint->connection_family);
+			BC_ASSERT_TRUE(family_found==endpoint->connection_family);
 		}
 		break;
 	case 401:endpoint->stat.fourHundredOne++; break;
@@ -341,7 +356,7 @@ static void destroy_endpoint(endpoint_t* endpoint) {
 
 static endpoint_t* create_udp_endpoint(int port,belle_sip_listener_callbacks_t* listener_callbacks) {
 	endpoint_t *endpoint=create_endpoint("0.0.0.0",port,"udp",listener_callbacks);
-	CU_ASSERT_PTR_NOT_NULL_FATAL(endpoint->lp);
+	BC_ASSERT_PTR_NOT_NULL_FATAL(endpoint->lp);
 	return endpoint;
 }
 
@@ -399,33 +414,33 @@ static void refresher_base_with_body(endpoint_t* client
 		client->refresher= refresher = belle_sip_client_transaction_create_refresher(trans);
 	} else {
 		if (server->auth == none) {
-			CU_ASSERT_TRUE(wait_for(server->stack,client->stack,&client->stat.twoHundredOk,1,1000));
+			BC_ASSERT_TRUE(wait_for(server->stack,client->stack,&client->stat.twoHundredOk,1,1000));
 		} else {
-			CU_ASSERT_TRUE(wait_for(server->stack,client->stack,&client->stat.fourHundredOne,1,1000));
+			BC_ASSERT_TRUE(wait_for(server->stack,client->stack,&client->stat.fourHundredOne,1,1000));
 			/*update cseq*/
 			req=belle_sip_client_transaction_create_authenticated_request(trans,NULL,NULL);
 			belle_sip_object_unref(trans);
 			trans=belle_sip_provider_create_client_transaction(client->provider,req);
 			belle_sip_object_ref(trans);
 			belle_sip_client_transaction_send_request(trans);
-			CU_ASSERT_TRUE_FATAL(wait_for(server->stack,client->stack,&client->stat.twoHundredOk,1,1000));
+			BC_ASSERT_TRUE_FATAL(wait_for(server->stack,client->stack,&client->stat.twoHundredOk,1,1000));
 		}
 		client->refresher= refresher = belle_sip_client_transaction_create_refresher(trans);
 	}
-	CU_ASSERT_TRUE_FATAL(refresher!=NULL);
+	BC_ASSERT_TRUE_FATAL(refresher!=NULL);
 	belle_sip_object_unref(trans);
 	belle_sip_refresher_set_listener(refresher,belle_sip_refresher_listener,client);
 
 	begin = belle_sip_time_ms();
-	CU_ASSERT_TRUE(wait_for(server->stack,client->stack,&client->stat.refreshOk,client->register_count+(client->early_refresher?1:0),client->register_count*1000 + 1000));
+	BC_ASSERT_TRUE(wait_for(server->stack,client->stack,&client->stat.refreshOk,client->register_count+(client->early_refresher?1:0),client->register_count*1000 + 1000));
 	end = belle_sip_time_ms();
-	CU_ASSERT_TRUE(end-begin>=client->register_count*1000*.9); /*because refresh is at 90% of expire*/
-	CU_ASSERT_TRUE(end-begin<(client->register_count*1000 + 2000));
+	BC_ASSERT_TRUE(end-begin>=client->register_count*1000*.9); /*because refresh is at 90% of expire*/
+	BC_ASSERT_TRUE(end-begin<(client->register_count*1000 + 2000));
 	/*unregister twice to make sure refresh operation can be safely cascaded*/
 	belle_sip_refresher_refresh(refresher,0);
 	belle_sip_refresher_refresh(refresher,0);
-	CU_ASSERT_TRUE(wait_for(server->stack,client->stack,&client->stat.refreshOk,client->register_count+1,1000));
-	CU_ASSERT_EQUAL(client->stat.refreshOk,client->register_count+1);
+	BC_ASSERT_TRUE(wait_for(server->stack,client->stack,&client->stat.refreshOk,client->register_count+1,1000));
+	BC_ASSERT_EQUAL(client->stat.refreshOk,client->register_count+1,int,"%d");
 	belle_sip_refresher_stop(refresher);
 	belle_sip_object_unref(refresher);
 }
@@ -465,6 +480,7 @@ static void refresher_base_with_param(const char* method, unsigned char expire_i
 static void register_test_with_param(unsigned char expire_in_contact,auth_mode_t auth_mode) {
 	refresher_base_with_param("REGISTER",expire_in_contact,auth_mode);
 }
+
 static void subscribe_test(void) {
 	belle_sip_listener_callbacks_t client_callbacks;
 	belle_sip_listener_callbacks_t server_callbacks;
@@ -482,10 +498,12 @@ static void subscribe_test(void) {
 	memset(&client_callbacks,0,sizeof(belle_sip_listener_callbacks_t));
 	memset(&server_callbacks,0,sizeof(belle_sip_listener_callbacks_t));
 
+	client_callbacks.process_dialog_terminated=client_process_dialog_terminated;
 	client_callbacks.process_response_event=client_process_response_event;
 	client_callbacks.process_auth_requested=client_process_auth_requested;
 	server_callbacks.process_request_event=server_process_request_event;
-
+	server_callbacks.process_dialog_terminated=server_process_dialog_terminated;
+	
 	client = create_udp_endpoint(3452,&client_callbacks);
 	server = create_udp_endpoint(6788,&server_callbacks);
 	server->expire_in_contact=0;
@@ -514,31 +532,33 @@ static void subscribe_test(void) {
 	belle_sip_object_ref(trans);/*to avoid trans from being deleted before refresher can use it*/
 	belle_sip_client_transaction_send_request(trans);
 
-	CU_ASSERT_TRUE(wait_for(server->stack,client->stack,&client->stat.fourHundredOne,1,1000));
+	BC_ASSERT_TRUE(wait_for(server->stack,client->stack,&client->stat.fourHundredOne,1,1000));
 
 	req=belle_sip_client_transaction_create_authenticated_request(trans,NULL,NULL);
 	belle_sip_object_unref(trans);
 	trans=belle_sip_provider_create_client_transaction(client->provider,req);
 	belle_sip_object_ref(trans);
 	belle_sip_client_transaction_send_request(trans);
-	CU_ASSERT_TRUE_FATAL(wait_for(server->stack,client->stack,&client->stat.twoHundredOk,1,1000));
+	BC_ASSERT_TRUE_FATAL(wait_for(server->stack,client->stack,&client->stat.twoHundredOk,1,1000));
 	 /*maybe dialog should be automatically created*/
-	CU_ASSERT_PTR_NOT_NULL_FATAL(belle_sip_transaction_get_dialog(BELLE_SIP_TRANSACTION(trans)))
+	BC_ASSERT_PTR_NOT_NULL_FATAL(belle_sip_transaction_get_dialog(BELLE_SIP_TRANSACTION(trans)));
 
 	refresher = belle_sip_client_transaction_create_refresher(trans);
 	belle_sip_object_unref(trans);
 	belle_sip_refresher_set_listener(refresher,belle_sip_refresher_listener,client);
 
 	begin = belle_sip_time_ms();
-	CU_ASSERT_TRUE(wait_for(server->stack,client->stack,&client->stat.refreshOk,3,4000));
+	BC_ASSERT_TRUE(wait_for(server->stack,client->stack,&client->stat.refreshOk,3,4000));
 	end = belle_sip_time_ms();
-	CU_ASSERT_TRUE(end-begin>=3000);
-	CU_ASSERT_TRUE(end-begin<5000);
+	BC_ASSERT_TRUE(end-begin>=3000);
+	BC_ASSERT_TRUE(end-begin<5000);
 	/*unsubscribe twice to make sure refresh operation can be safely cascaded*/
 	belle_sip_refresher_refresh(refresher,0);
 	belle_sip_refresher_refresh(refresher,0);
 
 	belle_sip_refresher_stop(refresher);
+	BC_ASSERT_TRUE(wait_for(server->stack,client->stack,&client->stat.dialogTerminated,1,4000));
+	BC_ASSERT_TRUE(wait_for(server->stack,client->stack,&server->stat.dialogTerminated,1,4000));
 	belle_sip_object_unref(refresher);
 	destroy_endpoint(client);
 	destroy_endpoint(server);
@@ -575,7 +595,7 @@ static void register_with_failure(void) {
 	server->auth=digest;
 	client->transiant_network_failure=1;
 	register_base(client,server);
-	CU_ASSERT_EQUAL(client->stat.refreshKo,1);
+	BC_ASSERT_EQUAL(client->stat.refreshKo,1,int,"%d");
 	destroy_endpoint(client);
 	destroy_endpoint(server);
 }
@@ -758,12 +778,12 @@ static void register_tcp_test_ipv6_random_port(void){
 	register_test_with_random_port("tcp","::0","0.0.0.0",AF_INET);
 }
 
-static void simple_publish() {
+static void simple_publish(void) {
 	belle_sip_header_content_type_t* content_type=belle_sip_header_content_type_create("application","pidf+xml");
 	refresher_base_with_param_and_body("PUBLISH",FALSE,TRUE,FALSE, content_type,publish_body);
 
 }
-static void simple_publish_with_early_refresher() {
+static void simple_publish_with_early_refresher(void) {
 	belle_sip_header_content_type_t* content_type=belle_sip_header_content_type_create("application","pidf+xml");
 	refresher_base_with_param_and_body("PUBLISH",FALSE,TRUE,TRUE, content_type,publish_body);
 
@@ -794,11 +814,5 @@ test_t refresher_tests[] = {
 	{ "REGISTER TCP from random port using AF_INET6", register_tcp_test_ipv6_random_port },
 };
 
-test_suite_t refresher_test_suite = {
-	"Refresher",
-	NULL,
-	NULL,
-	sizeof(refresher_tests) / sizeof(refresher_tests[0]),
-	refresher_tests
-};
-
+test_suite_t refresher_test_suite = {"Refresher", NULL, NULL, belle_sip_tester_before_each, belle_sip_tester_after_each,
+									 sizeof(refresher_tests) / sizeof(refresher_tests[0]), refresher_tests};
