@@ -16,8 +16,6 @@
 	along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include <stdio.h>
-#include "CUnit/Basic.h"
 #include "belle-sip/belle-sip.h"
 #include "belle_sip_internal.h"
 #include "belle_sip_tester.h"
@@ -32,6 +30,8 @@ const char *client_auth_outbound_proxy="sips:sip2.linphone.org:5063";
 const char *no_server_running_here="sip:test.linphone.org:3;transport=tcp";
 const char *no_response_here="sip:78.220.48.77:3;transport=%s";
 const char *test_domain_tls_to_tcp="sip:sip2.linphone.org:5060;transport=tls";
+const char *test_http_proxy_addr="sip.linphone.org";
+int test_http_proxy_port = 3128 ;
 
 static int is_register_ok;
 static int number_of_challenge;
@@ -58,7 +58,7 @@ static void process_io_error(void *user_ctx, const belle_sip_io_error_event_t *e
 	belle_sip_message("process_io_error, exiting main loop");
 	belle_sip_main_loop_quit(belle_sip_stack_get_main_loop(stack));
 	io_error_count++;
-	/*CU_ASSERT(CU_FALSE);*/
+	/*BC_ASSERT(CU_FALSE);*/
 }
 
 static void process_request_event(void *user_ctx, const belle_sip_request_event_t *event){
@@ -71,7 +71,7 @@ static void process_response_event(void *user_ctx, const belle_sip_response_even
 	int status;
 	belle_sip_request_t* request;
 	BELLESIP_UNUSED(user_ctx);
-	CU_ASSERT_PTR_NOT_NULL_FATAL(belle_sip_response_event_get_response(event));
+	BC_ASSERT_PTR_NOT_NULL_FATAL(belle_sip_response_event_get_response(event));
 	belle_sip_message("process_response_event [%i] [%s]"
 					,status=belle_sip_response_get_status_code(belle_sip_response_event_get_response(event))
 					,belle_sip_response_get_reason_phrase(belle_sip_response_event_get_response(event)));
@@ -81,15 +81,15 @@ static void process_response_event(void *user_ctx, const belle_sip_response_even
 		belle_sip_header_cseq_t* cseq;
 		belle_sip_client_transaction_t *t;
 		belle_sip_uri_t *dest;
-		// CU_ASSERT_NOT_EQUAL_FATAL(number_of_challenge,2);
-		CU_ASSERT_PTR_NOT_NULL_FATAL(belle_sip_response_event_get_client_transaction(event)); /*require transaction mode*/
+		// BC_ASSERT_NOT_EQUAL_FATAL(number_of_challenge,2);
+		BC_ASSERT_PTR_NOT_NULL_FATAL(belle_sip_response_event_get_client_transaction(event)); /*require transaction mode*/
 		dest=belle_sip_client_transaction_get_route(belle_sip_response_event_get_client_transaction(event));
 		request=belle_sip_transaction_get_request(BELLE_SIP_TRANSACTION(belle_sip_response_event_get_client_transaction(event)));
 		cseq=(belle_sip_header_cseq_t*)belle_sip_message_get_header(BELLE_SIP_MESSAGE(request),BELLE_SIP_CSEQ);
 		belle_sip_header_cseq_set_seq_number(cseq,belle_sip_header_cseq_get_seq_number(cseq)+1);
 		belle_sip_message_remove_header(BELLE_SIP_MESSAGE(request),BELLE_SIP_AUTHORIZATION);
 		belle_sip_message_remove_header(BELLE_SIP_MESSAGE(request),BELLE_SIP_PROXY_AUTHORIZATION);
-		CU_ASSERT_TRUE_FATAL(belle_sip_provider_add_authorization(prov,request,belle_sip_response_event_get_response(event),NULL,NULL,auth_domain));
+		BC_ASSERT_TRUE_FATAL(belle_sip_provider_add_authorization(prov,request,belle_sip_response_event_get_response(event),NULL,NULL,auth_domain));
 
 		t=belle_sip_provider_create_client_transaction(prov,request);
 		belle_sip_client_transaction_send_request_to(t,dest);
@@ -97,7 +97,7 @@ static void process_response_event(void *user_ctx, const belle_sip_response_even
 		authorized_request=request;
 		belle_sip_object_ref(authorized_request);
 	}  else {
-		CU_ASSERT_EQUAL(status,200);
+		BC_ASSERT_EQUAL(status,200,int,"%d");
 		is_register_ok=1;
 		using_transaction=belle_sip_response_event_get_client_transaction(event)!=NULL;
 		belle_sip_main_loop_quit(belle_sip_stack_get_main_loop(stack));
@@ -188,7 +188,7 @@ static void process_auth_requested(void *user_ctx, belle_sip_auth_event_t *event
 	}
 }
 
-int register_init(void) {
+int register_before_all(void) {
 	belle_sip_listening_point_t *lp;
 	stack=belle_sip_stack_new(NULL);
 	lp=belle_sip_stack_create_listening_point(stack,"0.0.0.0",7060,"UDP");
@@ -218,7 +218,7 @@ int register_init(void) {
 	return 0;
 }
 
-int register_uninit(void) {
+int register_after_all(void) {
 	belle_sip_object_unref(prov);
 	belle_sip_object_unref(stack);
 	belle_sip_object_unref(listener);
@@ -256,8 +256,8 @@ void unregister_user(belle_sip_stack_t * stack
 		}
 	}
 
-	CU_ASSERT_EQUAL(is_register_ok,1);
-	CU_ASSERT_EQUAL(using_transaction,use_transaction);
+	BC_ASSERT_EQUAL(is_register_ok,1,int,"%d");
+	BC_ASSERT_EQUAL(using_transaction,use_transaction,int,"%d");
 	belle_sip_object_unref(req);
 	belle_sip_provider_remove_sip_listener(prov,l);
 }
@@ -275,6 +275,7 @@ belle_sip_request_t* try_register_user_at_domain(belle_sip_stack_t * stack
 	char uri[256];
 	int i;
 	char *outbound=NULL;
+	int do_manual_retransmissions = FALSE;
 
 	number_of_challenge=0;
 	if (transport)
@@ -313,16 +314,19 @@ belle_sip_request_t* try_register_user_at_domain(belle_sip_stack_t * stack
 	if (use_transaction){
 		belle_sip_client_transaction_t *t=belle_sip_provider_create_client_transaction(prov,req);
 		belle_sip_client_transaction_send_request_to(t,outbound?belle_sip_uri_parse(outbound):NULL);
-	}else belle_sip_provider_send_request(prov,req);
+	}else{
+		belle_sip_provider_send_request(prov,req);
+		do_manual_retransmissions = (transport == NULL) || (strcasecmp(transport,"udp") == 0);
+	}
 	for(i=0;!is_register_ok && i<20 && io_error_count==0;i++) {
 		belle_sip_stack_sleep(stack,500);
-		if (!use_transaction && !is_register_ok) {
+		if (do_manual_retransmissions && !is_register_ok) {
 			belle_sip_object_ref(req);
 			belle_sip_provider_send_request(prov,req); /*manage retransmitions*/
 		}
 	}
-	CU_ASSERT_EQUAL(is_register_ok,success_expected);
-	if (success_expected) CU_ASSERT_EQUAL(using_transaction,use_transaction);
+	BC_ASSERT_EQUAL(is_register_ok,success_expected,int,"%d");
+	if (success_expected) BC_ASSERT_EQUAL(using_transaction,use_transaction,int,"%d");
 
 	belle_sip_object_unref(req);
 	belle_sip_provider_remove_sip_listener(prov,l);
@@ -413,6 +417,38 @@ static void stateful_register_tls(void){
 	register_test("tls",1);
 }
 
+static void stateful_register_tls_with_http_proxy(void) {
+	belle_sip_tls_listening_point_t * lp = (belle_sip_tls_listening_point_t*)belle_sip_provider_get_listening_point(prov, "tls");
+	if (!lp) {
+		belle_sip_error("No TLS support, test skipped.");
+		return;
+	}
+	belle_sip_provider_clean_channels(prov);
+	belle_sip_stack_set_http_proxy_host(stack, test_http_proxy_addr);
+	belle_sip_stack_set_http_proxy_port(stack, test_http_proxy_port);
+	register_test("tls",1);
+	belle_sip_stack_set_http_proxy_host(stack, NULL);
+	belle_sip_stack_set_http_proxy_port(stack, 0);
+
+}
+
+static void stateful_register_tls_with_wrong_http_proxy(void){
+	
+	belle_sip_tls_listening_point_t * lp = (belle_sip_tls_listening_point_t*)belle_sip_provider_get_listening_point(prov, "tls");
+	if (!lp) {
+		belle_sip_error("No TLS support, test skipped.");
+		return;
+	}
+	belle_sip_provider_clean_channels(prov);
+	belle_sip_stack_set_http_proxy_host(stack, "mauvaisproxy.linphone.org");
+	belle_sip_stack_set_http_proxy_port(stack, test_http_proxy_port);
+	try_register_user_at_domain(stack,prov,"tls",1,"tester",test_domain,NULL,0);
+	belle_sip_stack_set_http_proxy_host(stack, NULL);
+	belle_sip_stack_set_http_proxy_port(stack, 0);
+	
+}
+
+
 static void bad_req_process_io_error(void *user_ctx, const belle_sip_io_error_event_t *event){
 	BELLESIP_UNUSED(user_ctx);
 	BELLESIP_UNUSED(event);
@@ -420,11 +456,13 @@ static void bad_req_process_io_error(void *user_ctx, const belle_sip_io_error_ev
 }
 
 static void bad_req_process_response_event(void *user_ctx, const belle_sip_response_event_t *event){
-	int *bad_request_response_received=(int*)user_ctx;
 	belle_sip_response_t *resp=belle_sip_response_event_get_response(event);
-	CU_ASSERT_TRUE(resp && belle_sip_response_get_status_code(resp)==400);
-	*bad_request_response_received=1;
-	belle_sip_main_loop_quit(belle_sip_stack_get_main_loop(stack));
+	int *bad_request_response_received=(int*)user_ctx;
+	if (belle_sip_response_event_get_client_transaction(event) != NULL) {
+		BC_ASSERT_TRUE(resp && belle_sip_response_get_status_code(resp)==400);
+		*bad_request_response_received=1;
+		belle_sip_main_loop_quit(belle_sip_stack_get_main_loop(stack));
+	}
 }
 
 static void test_bad_request(void) {
@@ -465,7 +503,7 @@ static void test_bad_request(void) {
 	t=belle_sip_provider_create_client_transaction(prov,req);
 	belle_sip_client_transaction_send_request(t);
 	belle_sip_stack_sleep(stack,3000);
-	CU_ASSERT_TRUE(bad_request_response_received==1);
+	BC_ASSERT_TRUE(bad_request_response_received==1);
 	belle_sip_provider_remove_sip_listener(prov,bad_req_listener);
 	belle_sip_object_unref(bad_req_listener);
 
@@ -486,14 +524,14 @@ static void test_register_authenticate(void) {
 
 static void test_register_channel_inactive(void){
 	belle_sip_listening_point_t *lp=belle_sip_provider_get_listening_point(prov,"TCP");
-	CU_ASSERT_PTR_NOT_NULL_FATAL(lp);
+	BC_ASSERT_PTR_NOT_NULL_FATAL(lp);
 	belle_sip_stack_set_inactive_transport_timeout(stack,5);
 	belle_sip_listening_point_clean_channels(lp);
-	CU_ASSERT_EQUAL(belle_sip_listening_point_get_channel_count(lp),0);
+	BC_ASSERT_EQUAL(belle_sip_listening_point_get_channel_count(lp),0,int,"%d");
 	register_test("tcp",1);
-	CU_ASSERT_EQUAL(belle_sip_listening_point_get_channel_count(lp),1);
+	BC_ASSERT_EQUAL(belle_sip_listening_point_get_channel_count(lp),1,int,"%d");
 	belle_sip_stack_sleep(stack,5000);
-	CU_ASSERT_EQUAL(belle_sip_listening_point_get_channel_count(lp),0);
+	BC_ASSERT_EQUAL(belle_sip_listening_point_get_channel_count(lp),0,int,"%d");
 	belle_sip_stack_set_inactive_transport_timeout(stack,3600);
 }
 
@@ -517,7 +555,7 @@ static void test_connection_failure(void){
 	belle_sip_request_t *req;
 	io_error_count=0;
 	req=try_register_user_at_domain(stack, prov, "TCP",1,"tester","sip.linphone.org",no_server_running_here,0);
-	CU_ASSERT_TRUE(io_error_count>=1);
+	BC_ASSERT_TRUE(io_error_count>=1);
 	if (req) belle_sip_object_unref(req);
 }
 
@@ -526,9 +564,13 @@ static void test_connection_too_long(const char *transport){
 	int orig=belle_sip_stack_get_transport_timeout(stack);
 	char *no_response_here_with_transport = belle_sip_strdup_printf(no_response_here, transport);
 	io_error_count=0;
+	if (transport && strcasecmp("tls",transport)==0 && belle_sip_provider_get_listening_point(prov,"tls")==NULL){
+		belle_sip_error("No TLS support, test skipped.");
+		return;
+	}
 	belle_sip_stack_set_transport_timeout(stack,2000);
 	req=try_register_user_at_domain(stack, prov, transport,1,"tester","sip.linphone.org",no_response_here_with_transport,0);
-	CU_ASSERT_TRUE(io_error_count>=1);
+	BC_ASSERT_GREATER(io_error_count, 1, int, "%d");
 	belle_sip_stack_set_transport_timeout(stack,orig);
 	belle_sip_free(no_response_here_with_transport);
 	if (req) belle_sip_object_unref(req);
@@ -549,7 +591,7 @@ static void test_tls_to_tcp(void){
 	belle_sip_stack_set_transport_timeout(stack,2000);
 	req=try_register_user_at_domain(stack, prov, "TLS",1,"tester",test_domain,test_domain_tls_to_tcp,0);
 	if (req){
-		CU_ASSERT_TRUE(io_error_count>=1);
+		BC_ASSERT_TRUE(io_error_count>=1);
 		belle_sip_object_unref(req);
 	}
 	belle_sip_stack_set_transport_timeout(stack,orig);
@@ -559,7 +601,7 @@ static void register_dns_srv_tcp(void){
 	belle_sip_request_t *req;
 	io_error_count=0;
 	req=try_register_user_at_domain(stack, prov, "TCP",1,"tester",client_auth_domain,"sip:linphone.net;transport=tcp",1);
-	CU_ASSERT_TRUE(io_error_count==0);
+	BC_ASSERT_TRUE(io_error_count==0);
 	if (req) belle_sip_object_unref(req);
 }
 
@@ -567,7 +609,25 @@ static void register_dns_srv_tls(void){
 	belle_sip_request_t *req;
 	io_error_count=0;
 	req=try_register_user_at_domain(stack, prov, "TLS",1,"tester",client_auth_domain,"sip:linphone.net;transport=tls",1);
-	CU_ASSERT_TRUE(io_error_count==0);
+	BC_ASSERT_EQUAL(io_error_count, 0, int, "%d");
+	if (req) belle_sip_object_unref(req);
+}
+
+static void register_dns_srv_tls_with_http_proxy(void){
+	belle_sip_request_t *req;
+	belle_sip_tls_listening_point_t * lp = (belle_sip_tls_listening_point_t*)belle_sip_provider_get_listening_point(prov, "tls");
+	if (!lp) {
+		belle_sip_error("No TLS support, test skipped.");
+		return;
+	}
+	io_error_count=0;
+	belle_sip_provider_clean_channels(prov);
+	belle_sip_stack_set_http_proxy_host(stack, test_http_proxy_addr);
+	belle_sip_stack_set_http_proxy_port(stack, test_http_proxy_port);
+	req=try_register_user_at_domain(stack, prov, "TLS",1,"tester",client_auth_domain,"sip:linphone.net;transport=tls",1);
+	belle_sip_stack_set_http_proxy_host(stack, NULL);
+	belle_sip_stack_set_http_proxy_port(stack, 0);
+	BC_ASSERT_EQUAL(io_error_count, 0, int, "%d");
 	if (req) belle_sip_object_unref(req);
 }
 
@@ -575,14 +635,14 @@ static void register_dns_load_balancing(void) {
 	belle_sip_request_t *req;
 	io_error_count = 0;
 	req = try_register_user_at_domain(stack, prov, "TCP", 1, "tester", client_auth_domain, "sip:belle-sip.net;transport=tcp", 1);
-	CU_ASSERT_TRUE(io_error_count == 0);
+	BC_ASSERT_EQUAL(io_error_count, 0, int, "%d");
 	if (req) belle_sip_object_unref(req);
 }
 
 static void process_message_response_event(void *user_ctx, const belle_sip_response_event_t *event){
 	int status;
 	BELLESIP_UNUSED(user_ctx);
-	CU_ASSERT_PTR_NOT_NULL_FATAL(belle_sip_response_event_get_response(event));
+	BC_ASSERT_PTR_NOT_NULL_FATAL(belle_sip_response_event_get_response(event));
 	belle_sip_message("process_response_event [%i] [%s]"
 					,status=belle_sip_response_get_status_code(belle_sip_response_event_get_response(event))
 					,belle_sip_response_get_reason_phrase(belle_sip_response_event_get_response(event)));
@@ -630,7 +690,6 @@ static void reuse_nonce(void) {
 	int initial_auth_context_count=belle_sip_list_size(prov->auth_contexts);
 	register_request=register_user_at_domain(stack, prov, "tcp",1,"marie","sip.linphone.org",NULL);
 	if (register_request) {
-
 		char * first_nonce_used;
 		belle_sip_header_authorization_t * h = NULL;
 		belle_sip_request_t *message_request;
@@ -647,16 +706,16 @@ static void reuse_nonce(void) {
 		belle_sip_provider_add_sip_listener(prov,BELLE_SIP_LISTENER(listener));
 
 		/*currently only one nonce should have been used (the one for the REGISTER)*/
-		CU_ASSERT_EQUAL(belle_sip_list_size(prov->auth_contexts), initial_auth_context_count+1);
+		BC_ASSERT_EQUAL(belle_sip_list_size(prov->auth_contexts), initial_auth_context_count+1,int,"%d");
 
 		/*this should reuse previous nonce*/
 		message_request=send_message(register_request, auth_domain);
-		CU_ASSERT_EQUAL(is_register_ok, 404);
+		BC_ASSERT_EQUAL(is_register_ok, 404,int,"%d");
 		 h = BELLE_SIP_HEADER_AUTHORIZATION(belle_sip_message_get_header_by_type(
 					BELLE_SIP_MESSAGE(message_request), belle_sip_header_proxy_authorization_t
 				));
-		CU_ASSERT_PTR_NOT_NULL_FATAL(h);
-		CU_ASSERT_EQUAL(2, belle_sip_header_authorization_get_nonce_count(h));
+		BC_ASSERT_PTR_NOT_NULL_FATAL(h);
+		BC_ASSERT_EQUAL(2, belle_sip_header_authorization_get_nonce_count(h),int,"%d");
 		first_nonce_used = belle_sip_strdup(belle_sip_header_authorization_get_nonce(h));
 
 		belle_sip_object_unref(message_request);
@@ -664,32 +723,32 @@ static void reuse_nonce(void) {
 
 		/*new nonce should be created when not using outbound proxy realm*/
 		message_request=send_message(register_request, NULL);
-		CU_ASSERT_EQUAL(is_register_ok, 407);
+		BC_ASSERT_EQUAL(is_register_ok, 407,int,"%d");
 		h = BELLE_SIP_HEADER_AUTHORIZATION(belle_sip_message_get_header_by_type(
 				BELLE_SIP_MESSAGE(message_request), belle_sip_header_proxy_authorization_t
 			));
-		CU_ASSERT_PTR_NULL_FATAL(h);
+		BC_ASSERT_PTR_NULL_FATAL(h);
 		belle_sip_object_unref(message_request);
 
 
 		/*new nonce should be created here too*/
 		message_request=send_message(register_request, "wrongrealm");
-		CU_ASSERT_EQUAL(is_register_ok, 407);
+		BC_ASSERT_EQUAL(is_register_ok, 407,int,"%d");
 		h = BELLE_SIP_HEADER_AUTHORIZATION(belle_sip_message_get_header_by_type(
 				BELLE_SIP_MESSAGE(message_request), belle_sip_header_proxy_authorization_t
 			));
-		CU_ASSERT_PTR_NULL_FATAL(h);
+		BC_ASSERT_PTR_NULL_FATAL(h);
 		belle_sip_object_unref(message_request);
 
 
 		/*first nonce created should be reused*/
 		message_request=send_message(register_request, auth_domain);
-		CU_ASSERT_EQUAL(is_register_ok, 404);
+		BC_ASSERT_EQUAL(is_register_ok, 404,int,"%d");
 		h = BELLE_SIP_HEADER_AUTHORIZATION(belle_sip_message_get_header_by_type(
 				BELLE_SIP_MESSAGE(message_request), belle_sip_header_proxy_authorization_t
 			));
-		CU_ASSERT_PTR_NOT_NULL_FATAL(h);
-		CU_ASSERT_EQUAL(3, belle_sip_header_authorization_get_nonce_count(h));
+		BC_ASSERT_PTR_NOT_NULL_FATAL(h);
+		BC_ASSERT_EQUAL(3, belle_sip_header_authorization_get_nonce_count(h),int,"%d");
 		belle_sip_object_unref(message_request);
 
 		belle_sip_provider_remove_sip_listener(prov,BELLE_SIP_LISTENER(listener));
@@ -708,6 +767,8 @@ test_t register_tests[] = {
 	{ "Stateful UDP with outbound proxy", stateful_register_udp_with_outbound_proxy },
 	{ "Stateful TCP", stateful_register_tcp },
 	{ "Stateful TLS", stateful_register_tls },
+	{ "Stateful TLS with http proxy", stateful_register_tls_with_http_proxy },
+	{ "Stateful TLS with wrong http proxy", stateful_register_tls_with_wrong_http_proxy },
 	{ "Stateless UDP", stateless_register_udp },
 	{ "Stateless TCP", stateless_register_tcp },
 	{ "Stateless TLS", stateless_register_tls },
@@ -721,16 +782,11 @@ test_t register_tests[] = {
 	{ "TLS connection to TCP server", test_tls_to_tcp },
 	{ "Register with DNS SRV failover TCP", register_dns_srv_tcp },
 	{ "Register with DNS SRV failover TLS", register_dns_srv_tls },
+	{ "Register with DNS SRV failover TLS with http proxy", register_dns_srv_tls_with_http_proxy },
 	{ "Register with DNS load-balancing", register_dns_load_balancing },
 	{ "Nonce reutilization", reuse_nonce }
 };
 
-test_suite_t register_test_suite = {
-	"REGISTER",
-	register_init,
-	register_uninit,
-	sizeof(register_tests) / sizeof(register_tests[0]),
-	register_tests
-};
-
-
+test_suite_t register_test_suite = {"REGISTER", register_before_all, register_after_all, NULL,
+									NULL, sizeof(register_tests) / sizeof(register_tests[0]),
+									register_tests};
