@@ -21,14 +21,6 @@
 #include "belle_sip_tester.h"
 
 #include <belle-sip/utils.h>
-
-#include <stdio.h>
-#include "CUnit/Basic.h"
-#include "CUnit/MyMem.h"
-#include "CUnit/Automated.h"
-#ifdef HAVE_CU_CURSES
-#include "CUnit/CUCurses.h"
-#endif
 #include <belle-sip/belle-sip.h>
 
 #include "port.h"
@@ -41,6 +33,8 @@ static FILE * log_file = NULL;
 
 static belle_sip_object_pool_t *pool;
 
+static int leaked_objects_count;
+
 static int _belle_sip_tester_ipv6_available(void){
 	struct addrinfo *ai=belle_sip_ip_address_to_addrinfo(AF_INET6,"2a01:e00::2",53);
 	if (ai){
@@ -75,7 +69,7 @@ void belle_sip_tester_set_root_ca_path(const char *root_ca_path) {
 
 
 static void log_handler(int lev, const char *fmt, va_list args) {
-#ifdef WIN32
+#ifdef _WIN32
 	/* We must use stdio to avoid log formatting (for autocompletion etc.) */
 	vfprintf(lev == BELLE_SIP_LOG_ERROR ? stderr : stdout, fmt, args);
 	fprintf(lev == BELLE_SIP_LOG_ERROR ? stderr : stdout, "\n");
@@ -91,8 +85,9 @@ static void log_handler(int lev, const char *fmt, va_list args) {
 	}
 }
 
-void belle_sip_tester_init() {
-	bc_tester_init(log_handler, BELLE_SIP_LOG_MESSAGE, BELLE_SIP_LOG_ERROR);
+void belle_sip_tester_init(void(*ftester_printf)(int level, const char *fmt, va_list args)) {
+	if (ftester_printf == NULL) ftester_printf = log_handler;
+	bc_tester_init(ftester_printf, BELLE_SIP_LOG_MESSAGE, BELLE_SIP_LOG_ERROR);
 	belle_sip_init_sockets();
 	belle_sip_object_enable_marshal_check(TRUE);
 	ipv6_available=_belle_sip_tester_ipv6_available();
@@ -117,6 +112,38 @@ void belle_sip_tester_uninit(void) {
 	bc_tester_uninit();
 }
 
+void belle_sip_tester_before_each() {
+	belle_sip_object_enable_leak_detector(TRUE);
+	leaked_objects_count = belle_sip_object_get_object_count();
+}
+
+void belle_sip_tester_after_each() {
+	int leaked_objects = belle_sip_object_get_object_count() - leaked_objects_count;
+	BC_ASSERT_EQUAL(leaked_objects, 0, int, "%d");
+	if (leaked_objects > 0) {
+		belle_sip_object_dump_active_objects();
+		belle_sip_object_flush_active_objects();
+		belle_sip_error("%d objects were leaked in latest test, please fix that!\n", leaked_objects);
+	}
+}
+
+int belle_sip_tester_set_log_file(const char *filename) {
+	if (log_file) {
+		fclose(log_file);
+	}
+	log_file = fopen(filename, "w");
+	if (!log_file) {
+		belle_sip_error("Cannot open file [%s] for writing logs because [%s]", filename, strerror(errno));
+		return -1;
+	}
+	belle_sip_message("Redirecting traces to file [%s]", filename);
+	belle_sip_set_log_file(log_file);
+	return 0;
+}
+
+
+#if !defined(ANDROID) && !defined(TARGET_OS_IPHONE) && !(defined(BELLE_SIP_WINDOWS_PHONE) || defined(BELLE_SIP_WINDOWS_UNIVERSAL))
+
 static const char* belle_sip_helper =
 		"\t\t\t--verbose\n"
 		"\t\t\t--silent\n"
@@ -125,15 +152,25 @@ static const char* belle_sip_helper =
 		"\t\t\t--auth-domain <test auth domain>\n"
 		"\t\t\t--root-ca <root ca file path>\n";
 
-
-#if WINAPI_FAMILY_PARTITION(WINAPI_PARTITION_DESKTOP)
 int main (int argc, char *argv[]) {
 	int i;
 	int ret;
 	const char *root_ca_path = NULL;
 	const char *env_domain=getenv("TEST_DOMAIN");
 
-	belle_sip_tester_init();
+	belle_sip_tester_init(NULL);
+
+#ifndef WIN32   /*this hack doesn't work for argv[0]="c:\blablab\"*/
+	// this allows to launch liblinphone_tester from outside of tester directory
+	if (strstr(argv[0], ".libs")) {
+		int prefix_length = strstr(argv[0], ".libs") - argv[0] + 1;
+		char *prefix = belle_sip_strdup_printf("%s%.*s", argv[0][0] == '/' ? "" : "./", prefix_length, argv[0]);
+		// printf("Resource prefix set to %s\n", prefix);
+		bc_tester_set_resource_dir_prefix(prefix);
+		bc_tester_set_writable_dir_prefix(prefix);
+		belle_sip_free(prefix);
+	}
+#endif
 
 	if (env_domain) {
 		test_domain=env_domain;
@@ -146,14 +183,7 @@ int main (int argc, char *argv[]) {
 			belle_sip_set_log_level(BELLE_SIP_LOG_FATAL);
 		} else if (strcmp(argv[i],"--log-file")==0){
 			CHECK_ARG("--log-file", ++i, argc);
-			log_file=fopen(argv[i],"w");
-			if (!log_file) {
-				belle_sip_error("Cannot open file [%s] for writing logs because [%s]",argv[i],strerror(errno));
-				return -2;
-			} else {
-				belle_sip_message("Redirecting traces to file [%s]",argv[i]);
-				belle_sip_set_log_file(log_file);
-			}
+			if (belle_sip_tester_set_log_file(argv[i]) < 0) return -2;
 		} else if (strcmp(argv[i],"--domain")==0){
 			CHECK_ARG("--domain", ++i, argc);
 			test_domain=argv[i];
@@ -177,8 +207,9 @@ int main (int argc, char *argv[]) {
 	belle_sip_tester_set_root_ca_path(root_ca_path);
 	pool=belle_sip_object_pool_push();
 
-	ret = bc_tester_start();
+	ret = bc_tester_start(argv[0]);
 	belle_sip_tester_uninit();
 	return ret;
 }
+
 #endif
