@@ -19,10 +19,8 @@
 #ifndef _BELLE_SIP_TESTER_H
 #define _BELLE_SIP_TESTER_H
 
-
 #include "bc_tester_utils.h"
 
-
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -41,15 +39,20 @@ extern test_suite_t dialog_test_suite;
 extern test_suite_t refresher_test_suite;
 extern test_suite_t http_test_suite;
 
-extern int belle_sip_tester_ipv6_available(void);
-extern const char * belle_sip_tester_get_root_ca_path(void);
-extern void belle_sip_tester_set_root_ca_path(const char *root_ca_path);
-
 extern const char* belle_sip_tester_client_cert;
 extern const char* belle_sip_tester_client_cert_fingerprint;
 extern const char* belle_sip_tester_private_key;
 extern const char* belle_sip_tester_private_key_passwd;
 
+int belle_sip_tester_ipv6_available(void);
+const char * belle_sip_tester_get_root_ca_path(void);
+void belle_sip_tester_set_root_ca_path(const char *root_ca_path);
+void belle_sip_tester_init(void(*ftester_printf)(int level, const char *fmt, va_list args));
+void belle_sip_tester_uninit(void);
+void belle_sip_tester_before_each();
+void belle_sip_tester_after_each();
+int belle_sip_tester_set_log_file(const char *filename);
+
 #ifdef __cplusplus
 };
 #endif
